@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub name { 'epoll' }
 
@@ -36,12 +36,14 @@ sub extra_ldflags { '' }
 sub gen_create {
     my ($class, $builder, $listen_fd_var) = @_;
 
-    $builder->line('int ev_fd = epoll_create1(0);')
+    $builder->line('int ev_fd;')
+      ->line('struct epoll_event ev;')
+      ->blank
+      ->line('ev_fd = epoll_create1(0);')
       ->if('ev_fd < 0')
         ->line('croak("epoll_create1() failed");')
       ->endif
       ->blank
-      ->line('struct epoll_event ev;')
       ->line('ev.events = EPOLLIN | EPOLLET;')
       ->line("ev.data.fd = $listen_fd_var;")
       ->if("epoll_ctl(ev_fd, EPOLL_CTL_ADD, $listen_fd_var, &ev) < 0")
@@ -70,7 +72,8 @@ sub gen_del {
 sub gen_wait {
     my ($class, $builder, $loop_var, $events_var, $count_var, $timeout_var) = @_;
 
-    $builder->line("int $count_var = epoll_wait($loop_var, $events_var, MAX_EVENTS, $timeout_var);")
+    $builder->line("int $count_var;")
+      ->line("$count_var = epoll_wait($loop_var, $events_var, MAX_EVENTS, $timeout_var);")
       ->if("$count_var < 0")
         ->if('errno == EINTR')
           ->line('continue;')
@@ -84,7 +87,7 @@ sub gen_wait {
 sub gen_wait_once {
     my ($class, $builder, $loop_var, $events_var, $count_var, $timeout_ms) = @_;
 
-    $builder->line("int $count_var = epoll_wait($loop_var, $events_var, MAX_EVENTS, $timeout_ms);")
+    $builder->line("$count_var = epoll_wait($loop_var, $events_var, MAX_EVENTS, $timeout_ms);")
       ->line("if ($count_var < 0 && errno == EINTR) $count_var = 0;");
 }
 
@@ -92,7 +95,8 @@ sub gen_wait_once {
 sub gen_get_fd {
     my ($class, $builder, $events_var, $index_var, $fd_var) = @_;
 
-    $builder->line("int $fd_var = ${events_var}[$index_var].data.fd;");
+    $builder->line("int $fd_var;")
+      ->line("$fd_var = ${events_var}[$index_var].data.fd;");
 }
 
 # ============================================================
@@ -103,12 +107,13 @@ sub gen_get_fd {
 # Note: loop_var must be already declared
 sub gen_create_loop {
     my ($class, $builder, $loop_var) = @_;
-    
-    $builder->line("$loop_var = epoll_create1(0);")
+
+    $builder->line('struct epoll_event ev;')
+      ->blank
+      ->line("$loop_var = epoll_create1(0);")
       ->if("$loop_var < 0")
         ->line('croak("epoll_create1() failed");')
-      ->endif
-      ->line('struct epoll_event ev;');
+      ->endif;
 }
 
 # Generate: add fd with slot as user data
@@ -128,8 +133,9 @@ sub gen_add_with_slot {
 # Generate: extract slot from event data
 sub gen_get_slot {
     my ($class, $builder, $events_var, $index_var, $slot_var) = @_;
-    
-    $builder->line("int $slot_var = (int)${events_var}[$index_var].data.u32;");
+
+    $builder->line("int $slot_var;")
+      ->line("$slot_var = (int)${events_var}[$index_var].data.u32;");
 }
 
 # ============================================================
@@ -151,14 +157,15 @@ sub gen_add_multi_pool_notify {
     my ($class, $builder, $loop_var, $pool_slots_var, $pool_count_var) = @_;
 
     $builder->line("/* Add all pool notify fds to epoll */")
-            ->line("for (int _pi = 0; _pi < $pool_count_var; _pi++) {")
-            ->line("    int _pool_notify_fd = pool_get_notify_fd_slot($pool_slots_var\[_pi]);")
+            ->line("{ int _pi; int _pool_notify_fd;")
+            ->line("for (_pi = 0; _pi < $pool_count_var; _pi++) {")
+            ->line("    _pool_notify_fd = pool_get_notify_fd_slot($pool_slots_var\[_pi]);")
             ->line("    if (_pool_notify_fd >= 0) {")
             ->line("        ev.events = EPOLLIN;")
             ->line("        ev.data.fd = _pool_notify_fd;")
             ->line("        epoll_ctl($loop_var, EPOLL_CTL_ADD, _pool_notify_fd, &ev);")
             ->line("    }")
-            ->line("}");
+            ->line("} }");
 }
 
 1;
