@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub name { 'kqueue' }
 
@@ -36,12 +36,14 @@ sub extra_ldflags { '' }
 sub gen_create {
     my ($class, $builder, $listen_fd_var) = @_;
 
-    $builder->line('int ev_fd = kqueue();')
+    $builder->line('int ev_fd;')
+      ->line('struct kevent ev;')
+      ->blank
+      ->line('ev_fd = kqueue();')
       ->if('ev_fd < 0')
         ->line('croak("kqueue() failed");')
       ->endif
       ->blank
-      ->line('struct kevent ev;')
       ->line("EV_SET(&ev, $listen_fd_var, EVFILT_READ, EV_ADD | EV_ENABLE, 0, 0, NULL);")
       ->if("kevent(ev_fd, &ev, 1, NULL, 0, NULL) < 0")
         ->line('close(ev_fd);')
@@ -70,10 +72,12 @@ sub gen_wait {
     my ($class, $builder, $loop_var, $events_var, $count_var, $timeout_var) = @_;
 
     $builder->line('struct timespec ts;')
+      ->line("int $count_var;")
+      ->blank
       ->line("ts.tv_sec = $timeout_var / 1000;")
       ->line("ts.tv_nsec = ($timeout_var % 1000) * 1000000;")
       ->blank
-      ->line("int $count_var = kevent($loop_var, NULL, 0, $events_var, MAX_EVENTS, &ts);")
+      ->line("$count_var = kevent($loop_var, NULL, 0, $events_var, MAX_EVENTS, &ts);")
       ->if("$count_var < 0")
         ->if('errno == EINTR')
           ->line('continue;')
@@ -88,10 +92,11 @@ sub gen_wait_once {
     my ($class, $builder, $loop_var, $events_var, $count_var, $timeout_ms) = @_;
 
     $builder->line('struct timespec ts;')
+      ->blank
       ->line("ts.tv_sec = $timeout_ms / 1000;")
       ->line("ts.tv_nsec = ($timeout_ms % 1000) * 1000000;")
       ->blank
-      ->line("int $count_var = kevent($loop_var, NULL, 0, $events_var, MAX_EVENTS, &ts);")
+      ->line("$count_var = kevent($loop_var, NULL, 0, $events_var, MAX_EVENTS, &ts);")
       ->line("if ($count_var < 0 && errno == EINTR) $count_var = 0;");
 }
 
@@ -99,7 +104,8 @@ sub gen_wait_once {
 sub gen_get_fd {
     my ($class, $builder, $events_var, $index_var, $fd_var) = @_;
 
-    $builder->line("int $fd_var = (int)${events_var}[$index_var].ident;");
+    $builder->line("int $fd_var;")
+      ->line("$fd_var = (int)${events_var}[$index_var].ident;");
 }
 
 # ============================================================
@@ -110,12 +116,13 @@ sub gen_get_fd {
 # Note: loop_var must be already declared
 sub gen_create_loop {
     my ($class, $builder, $loop_var) = @_;
-    
-    $builder->line("$loop_var = kqueue();")
+
+    $builder->line('struct kevent ev;')
+      ->blank
+      ->line("$loop_var = kqueue();")
       ->if("$loop_var < 0")
         ->line('croak("kqueue() failed");')
-      ->endif
-      ->line('struct kevent ev;');
+      ->endif;
 }
 
 # Generate: add fd with slot as user data
@@ -136,8 +143,9 @@ sub gen_add_with_slot {
 # Generate: extract slot from event udata
 sub gen_get_slot {
     my ($class, $builder, $events_var, $index_var, $slot_var) = @_;
-    
-    $builder->line("int $slot_var = (int)(intptr_t)${events_var}[$index_var].udata;");
+
+    $builder->line("int $slot_var;")
+      ->line("$slot_var = (int)(intptr_t)${events_var}[$index_var].udata;");
 }
 
 # ============================================================
@@ -158,13 +166,14 @@ sub gen_add_multi_pool_notify {
     my ($class, $builder, $loop_var, $pool_slots_var, $pool_count_var) = @_;
 
     $builder->line("/* Add all pool notify fds to kqueue */")
-            ->line("for (int _pi = 0; _pi < $pool_count_var; _pi++) {")
-            ->line("    int _pool_notify_fd = pool_get_notify_fd_slot($pool_slots_var\[_pi]);")
+            ->line("{ int _pi; int _pool_notify_fd;")
+            ->line("for (_pi = 0; _pi < $pool_count_var; _pi++) {")
+            ->line("    _pool_notify_fd = pool_get_notify_fd_slot($pool_slots_var\[_pi]);")
             ->line("    if (_pool_notify_fd >= 0) {")
             ->line("        EV_SET(&ev, _pool_notify_fd, EVFILT_READ, EV_ADD | EV_ENABLE, 0, 0, NULL);")
             ->line("        kevent($loop_var, &ev, 1, NULL, 0, NULL);")
             ->line("    }")
-            ->line("}");
+            ->line("} }");
 }
 
 1;
