@@ -6,7 +6,7 @@ use 5.010;
 
 use parent 'Hypersonic::Event::Role';
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub name { 'poll' }
 
@@ -68,13 +68,14 @@ sub gen_del {
     my ($class, $builder, $loop_var, $fd_var) = @_;
 
     $builder->comment('Find and remove fd from poll array')
-      ->line('for (int j = 0; j < poll_nfds; j++) {')
+      ->line('{ int j;')
+      ->line('for (j = 0; j < poll_nfds; j++) {')
       ->line("    if (poll_fds[j].fd == $fd_var) {")
       ->line('        poll_fds[j] = poll_fds[poll_nfds - 1];')
       ->line('        poll_nfds--;')
       ->line('        break;')
       ->line('    }')
-      ->line('}');
+      ->line('} }');
 }
 
 # Wait using poll()
