@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # Hypersonic::Event::Role - Base class for event backends
 #
@@ -151,15 +151,16 @@ sub gen_add_multi_pool_notify {
     my ($class, $builder, $loop_var, $pool_slots_var, $pool_count_var) = @_;
 
     $builder->line("/* Add all pool notify fds to event loop */")
-            ->line("for (int _pi = 0; _pi < $pool_count_var; _pi++) {")
-            ->line("    int _pool_notify_fd = pool_get_notify_fd_slot($pool_slots_var\[_pi]);")
+            ->line("{ int _pi; int _pool_notify_fd;")
+            ->line("for (_pi = 0; _pi < $pool_count_var; _pi++) {")
+            ->line("    _pool_notify_fd = pool_get_notify_fd_slot($pool_slots_var\[_pi]);")
             ->line("    if (_pool_notify_fd >= 0) {");
 
     # Use the backend's gen_add method - inline the generated code
     $class->gen_add($builder, $loop_var, '_pool_notify_fd');
 
     $builder->line("    }")
-            ->line("}");
+            ->line("} }");
 }
 
 # Generate code to check if fd matches any pool's notify_fd
@@ -168,13 +169,14 @@ sub gen_check_multi_pool_notify {
     my ($class, $builder, $fd_var, $pool_slots_var, $pool_count_var, $matched_slot_var) = @_;
 
     $builder->line("int $matched_slot_var = -1;")
-            ->line("for (int _pi = 0; _pi < $pool_count_var; _pi++) {")
-            ->line("    int _pslot = $pool_slots_var\[_pi];")
+            ->line("{ int _pi; int _pslot;")
+            ->line("for (_pi = 0; _pi < $pool_count_var; _pi++) {")
+            ->line("    _pslot = $pool_slots_var\[_pi];")
             ->line("    if ($fd_var == pool_get_notify_fd_slot(_pslot)) {")
             ->line("        $matched_slot_var = _pslot;")
             ->line("        break;")
             ->line("    }")
-            ->line("}");
+            ->line("} }");
 }
 
 # Generate code to process a specific pool's completed operations
