@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # High-performance JIT-compiled Future for async operations
 # Serves as the foundation for all async in Hypersonic:
@@ -129,6 +129,7 @@ sub generate_c_code {
     $opts //= {};
     my $max_futures = $opts->{max_futures} // MAX_FUTURES;
     my $max_callbacks = $opts->{max_callbacks} // MAX_CALLBACKS;
+    my $inline = Hypersonic::JIT::Util->inline_keyword;
 
     # PERL_VERSION_* macros are already provided by XS::JIT preamble
     # No need to emit them here
@@ -302,15 +303,17 @@ sub _gen_custom_ops {
 
 sub _gen_helpers {
     my ($class, $builder) = @_;
+    my $inline = Hypersonic::JIT::Util->inline_keyword;
 
     # Forward declarations
     $builder->line('static void future_convergent_check(int parent_slot, int child_slot, int mask);')
             ->blank;
 
     # Freelist init - called once
-    $builder->line('static inline void future_freelist_init(void) {')
+    $builder->line("static $inline void future_freelist_init(void) {")
+            ->line('    int i;')
             ->line('    if (future_freelist_initialized) return;')
-            ->line('    for (int i = MAX_FUTURES - 1; i >= 0; i--) {')
+            ->line('    for (i = MAX_FUTURES - 1; i >= 0; i--) {')
             ->line('        future_freelist[future_freelist_count++] = i;')
             ->line('    }')
             ->line('    future_freelist_initialized = 1;')
@@ -318,7 +321,7 @@ sub _gen_helpers {
             ->blank;
 
     # Alloc slot - hot path optimized
-    $builder->line('static inline int future_alloc_slot(void) {')
+    $builder->line("static $inline int future_alloc_slot(void) {")
             ->line('    if (!future_freelist_initialized) future_freelist_init();')
             ->line('    if (future_freelist_count > 0) {')
             ->line('        int slot = future_freelist[--future_freelist_count];')
@@ -339,11 +342,12 @@ sub _gen_helpers {
 
     # Free slot
     $builder->line('static void future_free_slot(int slot) {')
+            ->line('    int i;')
             ->line('    if (slot < 0 || slot >= MAX_FUTURES) return;')
             ->line('    FutureContext *ctx = &future_registry[slot];')
             ->line('    if (!ctx->in_use) return;')
             ->line('    if (ctx->result_values) {')
-            ->line('        for (int i = 0; i < ctx->result_count; i++) {')
+            ->line('        for (i = 0; i < ctx->result_count; i++) {')
             ->line('            if (ctx->result_values[i]) SvREFCNT_dec(ctx->result_values[i]);')
             ->line('        }')
             ->line('        free(ctx->result_values);')
@@ -352,7 +356,7 @@ sub _gen_helpers {
             ->line('    }')
             ->line('    if (ctx->fail_message) { free(ctx->fail_message); ctx->fail_message = NULL; }')
             ->line('    if (ctx->fail_category) { free(ctx->fail_category); ctx->fail_category = NULL; }')
-            ->line('    for (int i = 0; i < ctx->callback_count; i++) {')
+            ->line('    for (i = 0; i < ctx->callback_count; i++) {')
             ->line('        if (ctx->callbacks[i].code) SvREFCNT_dec(ctx->callbacks[i].code);')
             ->line('    }')
             ->line('    if (ctx->subfuture_slots) { free(ctx->subfuture_slots); ctx->subfuture_slots = NULL; }')
@@ -368,8 +372,9 @@ sub _gen_helpers {
 
     # Invoke callbacks - NOT static so Pool.pm can access
     $builder->line('void future_invoke_callbacks(int slot, int mask) {')
+            ->line('    int i, j;')
             ->line('    FutureContext *ctx = &future_registry[slot];')
-            ->line('    for (int i = 0; i < ctx->callback_count; i++) {')
+            ->line('    for (i = 0; i < ctx->callback_count; i++) {')
             ->line('        FutureCallback *cb = &ctx->callbacks[i];')
             ->line('        if (!(cb->type & mask)) continue;')
             ->line('        if (cb->target_slot >= 0) {')
@@ -389,7 +394,7 @@ sub _gen_helpers {
             ->line('                    target->state = ctx->state;')
             ->line('                    if (ctx->state == FUTURE_STATE_DONE && ctx->result_count > 0) {')
             ->line('                        target->result_values = (SV **)malloc(ctx->result_count * sizeof(SV *));')
-            ->line('                        for (int j = 0; j < ctx->result_count; j++) {')
+            ->line('                        for (j = 0; j < ctx->result_count; j++) {')
             ->line('                            target->result_values[j] = SvREFCNT_inc(ctx->result_values[j]);')
             ->line('                        }')
             ->line('                        target->result_count = ctx->result_count;')
@@ -404,7 +409,7 @@ sub _gen_helpers {
             ->line('                    ENTER; SAVETMPS;')
             ->line('                    PUSHMARK(SP);')
             ->line('                    if (mask & FUTURE_CB_DONE) {')
-            ->line('                        for (int j = 0; j < ctx->result_count; j++) XPUSHs(ctx->result_values[j]);')
+            ->line('                        for (j = 0; j < ctx->result_count; j++) XPUSHs(ctx->result_values[j]);')
             ->line('                    } else if (mask & FUTURE_CB_FAIL) {')
             ->line('                        if (ctx->fail_message) XPUSHs(sv_2mortal(newSVpv(ctx->fail_message, 0)));')
             ->line('                        if (ctx->fail_category) XPUSHs(sv_2mortal(newSVpv(ctx->fail_category, 0)));')
@@ -414,7 +419,7 @@ sub _gen_helpers {
             ->line('                    SPAGAIN;')
             ->line('                    if (count > 0) {')
             ->line('                        target->result_values = (SV **)malloc(count * sizeof(SV *));')
-            ->line('                        for (int j = count - 1; j >= 0; j--) target->result_values[j] = SvREFCNT_inc(POPs);')
+            ->line('                        for (j = count - 1; j >= 0; j--) target->result_values[j] = SvREFCNT_inc(POPs);')
             ->line('                        target->result_count = count;')
             ->line('                    }')
             ->line('                    target->state = FUTURE_STATE_DONE;')
@@ -430,7 +435,7 @@ sub _gen_helpers {
             ->line('                        target->state = FUTURE_STATE_DONE;')
             ->line('                        if (ctx->result_count > 0) {')
             ->line('                            target->result_values = (SV **)malloc(ctx->result_count * sizeof(SV *));')
-            ->line('                            for (int j = 0; j < ctx->result_count; j++) {')
+            ->line('                            for (j = 0; j < ctx->result_count; j++) {')
             ->line('                                target->result_values[j] = SvREFCNT_inc(ctx->result_values[j]);')
             ->line('                            }')
             ->line('                            target->result_count = ctx->result_count;')
@@ -453,7 +458,7 @@ sub _gen_helpers {
             ->line('            ENTER; SAVETMPS;')
             ->line('            PUSHMARK(SP);')
             ->line('            if (mask & FUTURE_CB_DONE) {')
-            ->line('                for (int j = 0; j < ctx->result_count; j++) {')
+            ->line('                for (j = 0; j < ctx->result_count; j++) {')
             ->line('                    XPUSHs(ctx->result_values[j]);')
             ->line('                }')
             ->line('            } else if (mask & FUTURE_CB_FAIL) {')
@@ -470,6 +475,7 @@ sub _gen_helpers {
 
     # Convergent helper - called when a subfuture resolves
     $builder->line('static void future_convergent_check(int parent_slot, int child_slot, int mask) {')
+            ->line('    int i;')
             ->line('    FutureContext *parent = &future_registry[parent_slot];')
             ->line('    FutureContext *child = &future_registry[child_slot];')
             ->line('    if (parent->state != FUTURE_STATE_PENDING) return;')
@@ -490,7 +496,7 @@ sub _gen_helpers {
             ->line('                int count = parent->subfuture_count;')
             ->line('                parent->result_values = (SV**)malloc(count * sizeof(SV*));')
             ->line('                parent->result_count = 0;')
-            ->line('                for (int i = 0; i < count; i++) {')
+            ->line('                for (i = 0; i < count; i++) {')
             ->line('                    FutureContext *sub = &future_registry[parent->subfuture_slots[i]];')
             ->line('                    if (sub->result_count > 0) {')
             ->line('                        parent->result_values[parent->result_count++] = SvREFCNT_inc(sub->result_values[0]);')
@@ -506,7 +512,7 @@ sub _gen_helpers {
             ->line('            parent->state = FUTURE_STATE_DONE;')
             ->line('            if (child->result_count > 0) {')
             ->line('                parent->result_values = (SV**)malloc(child->result_count * sizeof(SV*));')
-            ->line('                for (int i = 0; i < child->result_count; i++) {')
+            ->line('                for (i = 0; i < child->result_count; i++) {')
             ->line('                    parent->result_values[i] = SvREFCNT_inc(child->result_values[i]);')
             ->line('                }')
             ->line('                parent->result_count = child->result_count;')
@@ -546,13 +552,14 @@ sub _gen_xs_functions {
     # xs_future_new_done - create already-done future in one call
     $builder->xs_function('xs_future_new_done')
             ->xs_preamble
+            ->line('int i;')
             ->line('int slot = future_alloc_slot();')
             ->line('if (slot < 0) croak("Future registry full");')
             ->line('FutureContext *ctx = &future_registry[slot];')
             ->line('int value_count = items - 1;')
             ->line('if (value_count > 0) {')
             ->line('    ctx->result_values = (SV **)malloc(value_count * sizeof(SV *));')
-            ->line('    for (int i = 0; i < value_count; i++) {')
+            ->line('    for (i = 0; i < value_count; i++) {')
             ->line('        ctx->result_values[i] = SvREFCNT_inc(ST(i + 1));')
             ->line('    }')
             ->line('    ctx->result_count = value_count;')
@@ -597,6 +604,7 @@ sub _gen_xs_functions {
     # xs_future_done
     $builder->xs_function('xs_future_done')
             ->xs_preamble
+            ->line('int i;')
             ->line('if (items < 1) croak("Usage: $future->done(@values)");')
             ->line('int slot = SvIV(SvRV(ST(0)));')
             ->line('FutureContext *ctx = &future_registry[slot];')
@@ -604,7 +612,7 @@ sub _gen_xs_functions {
             ->line('int value_count = items - 1;')
             ->line('if (value_count > 0) {')
             ->line('    ctx->result_values = (SV **)malloc(value_count * sizeof(SV *));')
-            ->line('    for (int i = 0; i < value_count; i++) {')
+            ->line('    for (i = 0; i < value_count; i++) {')
             ->line('        ctx->result_values[i] = SvREFCNT_inc(ST(i + 1));')
             ->line('    }')
             ->line('}')
@@ -684,11 +692,12 @@ sub _gen_xs_functions {
     # Result access
     $builder->xs_function('xs_future_result')
             ->xs_preamble
+            ->line('int i;')
             ->line('int slot = SvIV(SvRV(ST(0)));')
             ->line('FutureContext *ctx = &future_registry[slot];')
             ->line('if (ctx->state != FUTURE_STATE_DONE) croak("Future is not done");')
             ->line('SP -= items;')
-            ->line('for (int i = 0; i < ctx->result_count; i++) {')
+            ->line('for (i = 0; i < ctx->result_count; i++) {')
             ->line('    XPUSHs(ctx->result_values[i]);')
             ->line('}')
             ->line('PUTBACK;')
@@ -735,6 +744,7 @@ sub _gen_xs_functions {
 
     $builder->xs_function('xs_future_on_done')
             ->xs_preamble
+            ->line('int i;')
             ->line('if (items != 2) croak("Usage: $future->on_done($code)");')
             ->line('int slot = SvIV(SvRV(ST(0)));')
             ->line('FutureContext *ctx = &future_registry[slot];')
@@ -743,7 +753,7 @@ sub _gen_xs_functions {
             ->line('    dSP;')
             ->line('    ENTER; SAVETMPS;')
             ->line('    PUSHMARK(SP);')
-            ->line('    for (int i = 0; i < ctx->result_count; i++) XPUSHs(ctx->result_values[i]);')
+            ->line('    for (i = 0; i < ctx->result_count; i++) XPUSHs(ctx->result_values[i]);')
             ->line('    PUTBACK;')
             ->line('    call_sv(code, G_DISCARD);')
             ->line('    FREETMPS; LEAVE;')
@@ -808,6 +818,7 @@ sub _gen_xs_functions {
     # Sequencing: then
     $builder->xs_function('xs_future_then')
             ->xs_preamble
+            ->line('int i;')
             ->line('if (items != 2) croak("Usage: $future->then($code)");')
             ->line('int slot = SvIV(SvRV(ST(0)));')
             ->line('FutureContext *ctx = &future_registry[slot];')
@@ -822,13 +833,13 @@ sub _gen_xs_functions {
             ->line('    dSP;')
             ->line('    ENTER; SAVETMPS;')
             ->line('    PUSHMARK(SP);')
-            ->line('    for (int i = 0; i < ctx->result_count; i++) XPUSHs(ctx->result_values[i]);')
+            ->line('    for (i = 0; i < ctx->result_count; i++) XPUSHs(ctx->result_values[i]);')
             ->line('    PUTBACK;')
             ->line('    int count = call_sv(code, G_ARRAY);')
             ->line('    SPAGAIN;')
             ->line('    if (count > 0) {')
             ->line('        new_ctx->result_values = (SV **)malloc(count * sizeof(SV *));')
-            ->line('        for (int i = count - 1; i >= 0; i--) new_ctx->result_values[i] = SvREFCNT_inc(POPs);')
+            ->line('        for (i = count - 1; i >= 0; i--) new_ctx->result_values[i] = SvREFCNT_inc(POPs);')
             ->line('        new_ctx->result_count = count;')
             ->line('    }')
             ->line('    new_ctx->state = FUTURE_STATE_DONE;')
@@ -865,6 +876,7 @@ sub _gen_xs_functions {
     # Sequencing: catch
     $builder->xs_function('xs_future_catch')
             ->xs_preamble
+            ->line('int i;')
             ->line('if (items != 2) croak("Usage: $future->catch($code)");')
             ->line('int slot = SvIV(SvRV(ST(0)));')
             ->line('FutureContext *ctx = &future_registry[slot];')
@@ -886,7 +898,7 @@ sub _gen_xs_functions {
             ->line('    SPAGAIN;')
             ->line('    if (count > 0) {')
             ->line('        new_ctx->result_values = (SV **)malloc(count * sizeof(SV *));')
-            ->line('        for (int i = count - 1; i >= 0; i--) new_ctx->result_values[i] = SvREFCNT_inc(POPs);')
+            ->line('        for (i = count - 1; i >= 0; i--) new_ctx->result_values[i] = SvREFCNT_inc(POPs);')
             ->line('        new_ctx->result_count = count;')
             ->line('    }')
             ->line('    new_ctx->state = FUTURE_STATE_DONE;')
@@ -896,7 +908,7 @@ sub _gen_xs_functions {
             ->line('    new_ctx->state = FUTURE_STATE_DONE;')
             ->line('    if (ctx->result_count > 0) {')
             ->line('        new_ctx->result_values = (SV **)malloc(ctx->result_count * sizeof(SV *));')
-            ->line('        for (int i = 0; i < ctx->result_count; i++) new_ctx->result_values[i] = SvREFCNT_inc(ctx->result_values[i]);')
+            ->line('        for (i = 0; i < ctx->result_count; i++) new_ctx->result_values[i] = SvREFCNT_inc(ctx->result_values[i]);')
             ->line('        new_ctx->result_count = ctx->result_count;')
             ->line('    }')
             ->line('} else if (ctx->state == FUTURE_STATE_CANCELLED) {')
@@ -926,6 +938,7 @@ sub _gen_xs_functions {
     # Sequencing: finally
     $builder->xs_function('xs_future_finally')
             ->xs_preamble
+            ->line('int i;')
             ->line('if (items != 2) croak("Usage: $future->finally($code)");')
             ->line('int slot = SvIV(SvRV(ST(0)));')
             ->line('FutureContext *ctx = &future_registry[slot];')
@@ -946,7 +959,7 @@ sub _gen_xs_functions {
             ->line('    new_ctx->state = ctx->state;')
             ->line('    if (ctx->state == FUTURE_STATE_DONE && ctx->result_count > 0) {')
             ->line('        new_ctx->result_values = (SV **)malloc(ctx->result_count * sizeof(SV *));')
-            ->line('        for (int i = 0; i < ctx->result_count; i++) new_ctx->result_values[i] = SvREFCNT_inc(ctx->result_values[i]);')
+            ->line('        for (i = 0; i < ctx->result_count; i++) new_ctx->result_values[i] = SvREFCNT_inc(ctx->result_values[i]);')
             ->line('        new_ctx->result_count = ctx->result_count;')
             ->line('    } else if (ctx->state == FUTURE_STATE_FAILED) {')
             ->line('        if (ctx->fail_message) new_ctx->fail_message = strdup(ctx->fail_message);')
@@ -973,6 +986,7 @@ sub _gen_xs_functions {
     # Convergent: needs_all - all must succeed
     $builder->xs_function('xs_future_needs_all')
             ->xs_preamble
+            ->line('int i;')
             ->line('if (items < 2) croak("Usage: Hypersonic::Future->needs_all(@futures)");')
             ->line('int new_slot = future_alloc_slot();')
             ->line('if (new_slot < 0) croak("Future registry full");')
@@ -983,7 +997,7 @@ sub _gen_xs_functions {
             ->line('ctx->subfutures_pending = count;')
             ->line('ctx->convergent_mode = 1;')
             ->line('int all_done = 1;')
-            ->line('for (int i = 0; i < count; i++) {')
+            ->line('for (i = 0; i < count; i++) {')
             ->line('    SV *sub_sv = ST(i + 1);')
             ->line('    if (!sv_isobject(sub_sv)) croak("needs_all: argument %d is not a Future", i+1);')
             ->line('    int sub_slot = SvIV(SvRV(sub_sv));')
@@ -1015,7 +1029,7 @@ sub _gen_xs_functions {
             ->line('    /* All already done - collect results as flat list */')
             ->line('    ctx->result_values = (SV**)malloc(count * sizeof(SV*));')
             ->line('    ctx->result_count = 0;')
-            ->line('    for (int i = 0; i < count; i++) {')
+            ->line('    for (i = 0; i < count; i++) {')
             ->line('        FutureContext *sub = &future_registry[ctx->subfuture_slots[i]];')
             ->line('        if (sub->result_count > 0) {')
             ->line('            ctx->result_values[ctx->result_count++] = SvREFCNT_inc(sub->result_values[0]);')
@@ -1034,6 +1048,7 @@ sub _gen_xs_functions {
     # Convergent: needs_any - first success wins
     $builder->xs_function('xs_future_needs_any')
             ->xs_preamble
+            ->line('int i, j;')
             ->line('if (items < 2) croak("Usage: Hypersonic::Future->needs_any(@futures)");')
             ->line('int new_slot = future_alloc_slot();')
             ->line('if (new_slot < 0) croak("Future registry full");')
@@ -1043,7 +1058,7 @@ sub _gen_xs_functions {
             ->line('ctx->subfuture_count = count;')
             ->line('ctx->subfutures_pending = count;')
             ->line('ctx->convergent_mode = 2;')
-            ->line('for (int i = 0; i < count; i++) {')
+            ->line('for (i = 0; i < count; i++) {')
             ->line('    SV *sub_sv = ST(i + 1);')
             ->line('    if (!sv_isobject(sub_sv)) croak("needs_any: argument %d is not a Future", i+1);')
             ->line('    int sub_slot = SvIV(SvRV(sub_sv));')
@@ -1053,7 +1068,7 @@ sub _gen_xs_functions {
             ->line('        /* First success - use it */')
             ->line('        if (sub->result_count > 0) {')
             ->line('            ctx->result_values = (SV**)malloc(sub->result_count * sizeof(SV*));')
-            ->line('            for (int j = 0; j < sub->result_count; j++) {')
+            ->line('            for (j = 0; j < sub->result_count; j++) {')
             ->line('                ctx->result_values[j] = SvREFCNT_inc(sub->result_values[j]);')
             ->line('            }')
             ->line('            ctx->result_count = sub->result_count;')
@@ -1092,6 +1107,7 @@ sub _gen_xs_functions {
     # For now, they just return the convergent future (async behavior)
     $builder->xs_function('xs_future_wait_all')
             ->xs_preamble
+            ->line('int i;')
             ->line('/* Same as needs_all for now */')
             ->line('if (items < 2) croak("Usage: Hypersonic::Future->wait_all(@futures)");')
             ->line('int new_slot = future_alloc_slot();')
@@ -1103,7 +1119,7 @@ sub _gen_xs_functions {
             ->line('ctx->subfutures_pending = count;')
             ->line('ctx->convergent_mode = 1;')
             ->line('int all_done = 1;')
-            ->line('for (int i = 0; i < count; i++) {')
+            ->line('for (i = 0; i < count; i++) {')
             ->line('    SV *sub_sv = ST(i + 1);')
             ->line('    if (!sv_isobject(sub_sv)) croak("wait_all: argument %d is not a Future", i+1);')
             ->line('    int sub_slot = SvIV(SvRV(sub_sv));')
@@ -1131,7 +1147,7 @@ sub _gen_xs_functions {
             ->line('    /* All already done - collect results as flat list */')
             ->line('    ctx->result_values = (SV**)malloc(count * sizeof(SV*));')
             ->line('    ctx->result_count = 0;')
-            ->line('    for (int i = 0; i < count; i++) {')
+            ->line('    for (i = 0; i < count; i++) {')
             ->line('        FutureContext *sub = &future_registry[ctx->subfuture_slots[i]];')
             ->line('        if (sub->result_count > 0) {')
             ->line('            ctx->result_values[ctx->result_count++] = SvREFCNT_inc(sub->result_values[0]);')
@@ -1149,6 +1165,7 @@ sub _gen_xs_functions {
 
     $builder->xs_function('xs_future_wait_any')
             ->xs_preamble
+            ->line('int i, j;')
             ->line('/* Same as needs_any for now */')
             ->line('if (items < 2) croak("Usage: Hypersonic::Future->wait_any(@futures)");')
             ->line('int new_slot = future_alloc_slot();')
@@ -1159,7 +1176,7 @@ sub _gen_xs_functions {
             ->line('ctx->subfuture_count = count;')
             ->line('ctx->subfutures_pending = count;')
             ->line('ctx->convergent_mode = 2;')
-            ->line('for (int i = 0; i < count; i++) {')
+            ->line('for (i = 0; i < count; i++) {')
             ->line('    SV *sub_sv = ST(i + 1);')
             ->line('    if (!sv_isobject(sub_sv)) croak("wait_any: argument %d is not a Future", i+1);')
             ->line('    int sub_slot = SvIV(SvRV(sub_sv));')
@@ -1168,7 +1185,7 @@ sub _gen_xs_functions {
             ->line('    if (sub->state == FUTURE_STATE_DONE) {')
             ->line('        if (sub->result_count > 0) {')
             ->line('            ctx->result_values = (SV**)malloc(sub->result_count * sizeof(SV*));')
-            ->line('            for (int j = 0; j < sub->result_count; j++) {')
+            ->line('            for (j = 0; j < sub->result_count; j++) {')
             ->line('                ctx->result_values[j] = SvREFCNT_inc(sub->result_values[j]);')
             ->line('            }')
             ->line('            ctx->result_count = sub->result_count;')
@@ -1229,6 +1246,7 @@ sub _gen_xs_functions {
     # DESTROY
     $builder->xs_function('xs_future_destroy')
             ->xs_preamble
+            ->line('int i;')
             ->line('int slot = SvIV(SvRV(ST(0)));')
             ->line('if (slot >= 0 && slot < MAX_FUTURES) {')
             ->line('    FutureContext *ctx = &future_registry[slot];')
@@ -1236,7 +1254,7 @@ sub _gen_xs_functions {
             ->line('        ctx->refcount--;')
             ->line('        if (ctx->refcount <= 0) {')
             ->line('            /* Decrement refcounts of targets in unfired callbacks */')
-            ->line('            for (int i = 0; i < ctx->callback_count; i++) {')
+            ->line('            for (i = 0; i < ctx->callback_count; i++) {')
             ->line('                FutureCallback *cb = &ctx->callbacks[i];')
             ->line('                if (cb->target_slot >= 0 && cb->target_slot < MAX_FUTURES) {')
             ->line('                    FutureContext *target = &future_registry[cb->target_slot];')
