@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use XS::JIT::Builder;
 use Hypersonic::Future qw(MAX_FUTURES);
@@ -71,6 +71,7 @@ sub generate_c_code {
 
     $opts //= {};
     my $max_pools = $opts->{max_pools} // MAX_POOLS;
+    my $inline = Hypersonic::JIT::Util->inline_keyword;
 
     # PERL_VERSION_* macros are already provided by XS::JIT preamble
     # No need to emit them here
@@ -138,9 +139,10 @@ sub generate_c_code {
             ->blank;
 
     # Freelist init
-    $builder->line('static inline void pool_freelist_init(void) {')
+    $builder->line("static $inline void pool_freelist_init(void) {")
+            ->line('    int i;')
             ->line('    if (pool_freelist_initialized) return;')
-            ->line('    for (int i = MAX_POOLS - 1; i >= 0; i--) {')
+            ->line('    for (i = MAX_POOLS - 1; i >= 0; i--) {')
             ->line('        pool_freelist[pool_freelist_count++] = i;')
             ->line('    }')
             ->line('    pool_freelist_initialized = 1;')
@@ -148,7 +150,7 @@ sub generate_c_code {
             ->blank;
 
     # Alloc slot
-    $builder->line('static inline int pool_alloc_slot(void) {')
+    $builder->line("static $inline int pool_alloc_slot(void) {")
             ->line('    if (!pool_freelist_initialized) pool_freelist_init();')
             ->line('    if (pool_freelist_count > 0) {')
             ->line('        int slot = pool_freelist[--pool_freelist_count];')
@@ -373,6 +375,7 @@ sub _gen_xs_functions {
     # XS: init - initialize the pool (instance method)
     $builder->xs_function('xs_pool_init')
             ->xs_preamble
+            ->line('int i;')
             ->line('int slot = SvIV(SvRV(ST(0)));')
             ->line('PoolContext *pool = &pool_registry[slot];')
             ->line('if (pool->state == POOL_STATE_RUNNING) {')
@@ -394,7 +397,7 @@ sub _gen_xs_functions {
             ->line('pool->threads = (pthread_t*)malloc(pool->workers * sizeof(pthread_t));')
             ->line('if (!pool->threads) croak("malloc failed for threads");')
             ->line('pool->state = POOL_STATE_RUNNING;  /* Set BEFORE creating threads */')
-            ->line('for (int i = 0; i < pool->workers; i++) {')
+            ->line('for (i = 0; i < pool->workers; i++) {')
             ->line('    if (pthread_create(&pool->threads[i], NULL, pool_worker_fn, (void*)(intptr_t)slot) != 0) {')
             ->line('        croak("pthread_create failed");')
             ->line('    }')
@@ -406,6 +409,7 @@ sub _gen_xs_functions {
     # XS: shutdown - shutdown the pool (instance method)
     $builder->xs_function('xs_pool_shutdown')
             ->xs_preamble
+            ->line('int i;')
             ->line('int slot = SvIV(SvRV(ST(0)));')
             ->line('PoolContext *pool = &pool_registry[slot];')
             ->line('if (pool->state != POOL_STATE_RUNNING) {')
@@ -416,7 +420,7 @@ sub _gen_xs_functions {
             ->line('pool->state = POOL_STATE_SHUTDOWN;')
             ->line('pthread_cond_broadcast(&pool->cond);')
             ->line('pthread_mutex_unlock(&pool->mutex);')
-            ->line('for (int i = 0; i < pool->workers; i++) {')
+            ->line('for (i = 0; i < pool->workers; i++) {')
             ->line('    pthread_join(pool->threads[i], NULL);')
             ->line('}')
             ->line('#if USE_EVENTFD')
@@ -436,6 +440,7 @@ sub _gen_xs_functions {
     # Skip cleanup during global destruction (PL_dirty) - let OS clean up threads
     $builder->xs_function('xs_pool_destroy')
             ->xs_preamble
+            ->line('int i;')
             ->line('/* Skip during global destruction - pthread_join can hang/crash */')
             ->line('if (PL_dirty) XSRETURN(0);')
             ->line('int slot = SvIV(SvRV(ST(0)));')
@@ -447,7 +452,7 @@ sub _gen_xs_functions {
             ->line('        pool->state = POOL_STATE_SHUTDOWN;')
             ->line('        pthread_cond_broadcast(&pool->cond);')
             ->line('        pthread_mutex_unlock(&pool->mutex);')
-            ->line('        for (int i = 0; i < pool->workers; i++) {')
+            ->line('        for (i = 0; i < pool->workers; i++) {')
             ->line('            pthread_join(pool->threads[i], NULL);')
             ->line('        }')
             ->line('#if USE_EVENTFD')
@@ -508,6 +513,7 @@ sub _gen_xs_functions {
     # XS: process_ready - process completed ops (instance method)
     $builder->xs_function('xs_pool_process_ready')
             ->xs_preamble
+            ->line('int i;')
             ->line('int pool_slot = SvIV(SvRV(ST(0)));')
             ->line('PoolContext *pool = &pool_registry[pool_slot];')
             ->line('if (pool->state != POOL_STATE_RUNNING) { ST(0) = sv_2mortal(newSViv(0)); XSRETURN(1); }')
@@ -531,7 +537,7 @@ sub _gen_xs_functions {
             ->line('    if (op->args && SvROK(op->args)) {')
             ->line('        AV *args_av = (AV*)SvRV(op->args);')
             ->line('        int len = av_len(args_av) + 1;')
-            ->line('        for (int i = 0; i < len; i++) {')
+            ->line('        for (i = 0; i < len; i++) {')
             ->line('            SV **elem = av_fetch(args_av, i, 0);')
             ->line('            if (elem) XPUSHs(*elem);')
             ->line('        }')
@@ -557,7 +563,7 @@ sub _gen_xs_functions {
             ->line('        future_invoke_callbacks(op->future_slot, FUTURE_CB_FAIL);')
             ->line('    } else if (count > 0) {')
             ->line('        ctx->result_values = (SV**)malloc(count * sizeof(SV*));')
-            ->line('        for (int i = count - 1; i >= 0; i--) {')
+            ->line('        for (i = count - 1; i >= 0; i--) {')
             ->line('            ctx->result_values[i] = SvREFCNT_inc(POPs);')
             ->line('        }')
             ->line('        ctx->result_count = count;')
@@ -642,6 +648,7 @@ sub _gen_xs_functions {
     # XS: process_ready_slot (class method for event loop)
     $builder->xs_function('xs_pool_process_ready_slot')
             ->xs_preamble
+            ->line('int i;')
             ->line('if (items < 2) croak("Usage: Pool->_process_ready_slot($slot)");')
             ->line('int pool_slot = SvIV(ST(1));')
             ->line('if (pool_slot < 0 || pool_slot >= MAX_POOLS) { ST(0) = sv_2mortal(newSViv(0)); XSRETURN(1); }')
@@ -666,7 +673,7 @@ sub _gen_xs_functions {
             ->line('    if (op->args && SvROK(op->args)) {')
             ->line('        AV *args_av = (AV*)SvRV(op->args);')
             ->line('        int len = av_len(args_av) + 1;')
-            ->line('        for (int i = 0; i < len; i++) {')
+            ->line('        for (i = 0; i < len; i++) {')
             ->line('            SV **elem = av_fetch(args_av, i, 0);')
             ->line('            if (elem) XPUSHs(*elem);')
             ->line('        }')
@@ -691,7 +698,7 @@ sub _gen_xs_functions {
             ->line('        future_invoke_callbacks(op->future_slot, FUTURE_CB_FAIL);')
             ->line('    } else if (count > 0) {')
             ->line('        ctx->result_values = (SV**)malloc(count * sizeof(SV*));')
-            ->line('        for (int i = count - 1; i >= 0; i--) {')
+            ->line('        for (i = count - 1; i >= 0; i--) {')
             ->line('            ctx->result_values[i] = SvREFCNT_inc(POPs);')
             ->line('        }')
             ->line('        ctx->result_count = count;')
@@ -777,6 +784,7 @@ sub _gen_xs_functions {
     # XS: shutdown_global - shutdown default pool (class method)
     $builder->xs_function('xs_pool_shutdown_global')
             ->xs_preamble
+            ->line('int i;')
             ->line('if (default_pool_slot < 0) {')
             ->line('    ST(0) = sv_2mortal(newSViv(0));')
             ->line('    XSRETURN(1);')
@@ -790,7 +798,7 @@ sub _gen_xs_functions {
             ->line('pool->state = POOL_STATE_SHUTDOWN;')
             ->line('pthread_cond_broadcast(&pool->cond);')
             ->line('pthread_mutex_unlock(&pool->mutex);')
-            ->line('for (int i = 0; i < pool->workers; i++) {')
+            ->line('for (i = 0; i < pool->workers; i++) {')
             ->line('    pthread_join(pool->threads[i], NULL);')
             ->line('}')
             ->line('#if USE_EVENTFD')
