@@ -14,7 +14,7 @@ use warnings;
 # - Connection: keep-alive/close header
 # - Response format (HTTP/1.1 200 OK\r\nHeader: Value\r\n\r\nBody)
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # Protocol identifier - used for version negotiation
 sub protocol_id { 'HTTP/1.1' }
@@ -155,14 +155,17 @@ sub gen_path_parser {
     
     $builder->comment('HTTP/1.1: Find end of path (space before HTTP/1.1)')
       ->line('const char* path_end = path;')
+      ->line('int full_path_len;')
+      ->line('const char* query_pos;')
+      ->line('int path_len;')
       ->while('*path_end && *path_end != \' \'')
         ->line('path_end++;')
       ->endwhile
-      ->line('int full_path_len = path_end - path;')
+      ->line('full_path_len = path_end - path;')
       ->blank
       ->comment('Strip query string for route dispatch')
-      ->line('const char* query_pos = memchr(path, \'?\', full_path_len);')
-      ->line('int path_len = query_pos ? (query_pos - path) : full_path_len;');
+      ->line('query_pos = memchr(path, \'?\', full_path_len);')
+      ->line('path_len = query_pos ? (query_pos - path) : full_path_len;');
     
     return $builder;
 }
@@ -299,7 +302,7 @@ sub gen_chunked_write {
       ->line('    char size_line[32];')
       ->line('    int header_len = snprintf(size_line, sizeof(size_line), "%zx\\r\\n", len);')
       ->line('    ')
-      ->line('    // Use writev for efficiency (header + data + crlf in one syscall)')
+      ->line('    /* Use writev for efficiency (header + data + crlf in one syscall) */')
       ->line('    struct iovec iov[3];')
       ->line('    iov[0].iov_base = size_line;')
       ->line('    iov[0].iov_len = header_len;')
