@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # Session management for Hypersonic
 # Uses signed cookies for session ID, memory store for data
@@ -91,6 +91,7 @@ sub compile_session_ops {
     # --------------------------------------------------------
     $builder->xs_function('jit_hmac_sha256_hex')
       ->xs_preamble
+      ->line('int i;')
       ->line('if (items < 2) croak("Usage: _jit_hmac_sha256_hex(data, key, [output_len])");')
       ->line('STRLEN data_len, key_len;')
       ->line('const unsigned char* data = (const unsigned char*)SvPV(ST(0), data_len);')
@@ -106,7 +107,7 @@ sub compile_session_ops {
       ->line('char hex[129];')
       ->line('int hex_bytes = (int)(out_len / 2);')
       ->line('if (hex_bytes > 32) hex_bytes = 32;')
-      ->line('for (int i = 0; i < hex_bytes; i++) {')
+      ->line('for (i = 0; i < hex_bytes; i++) {')
       ->line('    sprintf(hex + i*2, "%02x", digest[i]);')
       ->line('}')
       ->line('hex[out_len] = \'\\0\';')
@@ -122,6 +123,7 @@ sub compile_session_ops {
     # --------------------------------------------------------
     $builder->xs_function('jit_constant_time_compare')
       ->xs_preamble
+      ->line('STRLEN i;')
       ->line('if (items != 2) croak("Usage: _jit_constant_time_compare(s1, s2)");')
       ->line('STRLEN len1, len2;')
       ->line('const unsigned char* s1 = (const unsigned char*)SvPV(ST(0), len1);')
@@ -131,7 +133,7 @@ sub compile_session_ops {
       ->line('STRLEN max_len = len1 > len2 ? len1 : len2;')
       ->line('unsigned char diff = (len1 != len2) ? 1 : 0;')
       ->blank
-      ->line('for (STRLEN i = 0; i < max_len; i++) {')
+      ->line('for (i = 0; i < max_len; i++) {')
       ->line('    unsigned char c1 = (i < len1) ? s1[i] : 0;')
       ->line('    unsigned char c2 = (i < len2) ? s2[i] : 0;')
       ->line('    diff |= c1 ^ c2;')
@@ -148,6 +150,7 @@ sub compile_session_ops {
     # --------------------------------------------------------
     $builder->xs_function('jit_generate_session_id')
       ->xs_preamble
+      ->line('int i;')
       ->line('unsigned char bytes[16];')
       ->blank
       ->comment('Try /dev/urandom first (most portable)')
@@ -167,7 +170,7 @@ sub compile_session_ops {
       ->blank
       ->comment('Convert to hex')
       ->line('char hex[33];')
-      ->line('for (int i = 0; i < 16; i++) {')
+      ->line('for (i = 0; i < 16; i++) {')
       ->line('    sprintf(hex + i*2, "%02x", bytes[i]);')
       ->line('}')
       ->line('hex[32] = \'\\0\';')
@@ -184,6 +187,7 @@ sub compile_session_ops {
     # --------------------------------------------------------
     $builder->xs_function('jit_verify_signature')
       ->xs_preamble
+      ->line('int i;')
       ->line('if (items != 2) croak("Usage: _jit_verify_signature(signed_cookie, secret)");')
       ->line('STRLEN cookie_len, secret_len;')
       ->line('const char* cookie = SvPV(ST(0), cookie_len);')
@@ -196,7 +200,7 @@ sub compile_session_ops {
       ->endif
       ->blank
       ->comment('Validate hex characters in session_id')
-      ->line('for (int i = 0; i < 32; i++) {')
+      ->line('for (i = 0; i < 32; i++) {')
       ->line('    char c = cookie[i];')
       ->line('    if (!((c >= \'0\' && c <= \'9\') || (c >= \'a\' && c <= \'f\'))) {')
       ->line('        ST(0) = &PL_sv_undef;')
@@ -219,14 +223,14 @@ sub compile_session_ops {
       ->blank
       ->comment('Convert first 8 bytes to hex (16 chars)')
       ->line('char expected[17];')
-      ->line('for (int i = 0; i < 8; i++) {')
+      ->line('for (i = 0; i < 8; i++) {')
       ->line('    sprintf(expected + i*2, "%02x", digest[i]);')
       ->line('}')
       ->line('expected[16] = \'\\0\';')
       ->blank
       ->comment('Constant-time comparison')
       ->line('unsigned char diff = 0;')
-      ->line('for (int i = 0; i < 16; i++) {')
+      ->line('for (i = 0; i < 16; i++) {')
       ->line('    diff |= expected[i] ^ provided_sig[i];')
       ->line('}')
       ->blank
