@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use XS::JIT;
 use XS::JIT::Builder;
@@ -58,25 +58,30 @@ sub compile_socket_ops {
     # Generate create_listen_socket
     $builder->xs_function('jit_create_listen_socket')
       ->xs_preamble
-      ->line('if (items != 1) croak("Usage: create_listen_socket(port)");')
-      ->line('IV port = SvIV(ST(0));')
+      ->line('IV port;')
+      ->line('int fd;')
+      ->line('int opt;')
+      ->line('int flags;')
+      ->line('struct sockaddr_in addr;')
       ->blank
-      ->line('int fd = socket(AF_INET, SOCK_STREAM, 0);')
+      ->line('if (items != 1) croak("Usage: create_listen_socket(port)");')
+      ->line('port = SvIV(ST(0));')
+      ->blank
+      ->line('fd = socket(AF_INET, SOCK_STREAM, 0);')
       ->if('fd < 0')
         ->line('ST(0) = sv_2mortal(newSViv(-1));')
         ->line('XSRETURN(1);')
       ->endif
       ->blank
-      ->line('int opt = 1;')
+      ->line('opt = 1;')
       ->line('setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(opt));')
       ->line('#ifdef SO_REUSEPORT')
       ->line('setsockopt(fd, SOL_SOCKET, SO_REUSEPORT, &opt, sizeof(opt));')
       ->line('#endif')
       ->blank
-      ->line('int flags = fcntl(fd, F_GETFL, 0);')
+      ->line('flags = fcntl(fd, F_GETFL, 0);')
       ->line('fcntl(fd, F_SETFL, flags | O_NONBLOCK);')
       ->blank
-      ->line('struct sockaddr_in addr;')
       ->line('memset(&addr, 0, sizeof(addr));')
       ->line('addr.sin_family = AF_INET;')
       ->line('addr.sin_port = htons((uint16_t)port);')
