@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant {
     STATE_INIT     => 0,
@@ -173,18 +173,22 @@ sub gen_xs_new {
       ->xs_preamble
       ->line('int fd = -1;')
       ->line('int http2 = 0;')
+      ->line('STRLEN klen;')
+      ->line('const char* key;')
+      ->line('STRLEN plen;')
+      ->line('const char* proto;')
+      ->line('SV* fd_sv;')
+      ->line('SV* ref;')
       ->blank
       ->comment('Parse hash args: new(fd => N) or new(fd => N, protocol => P)')
       ->for('int i = 1', 'i < items', 'i += 2')
         ->if('i + 1 < items')
-          ->line('STRLEN klen;')
-          ->line('const char* key = SvPV(ST(i), klen);')
+          ->line('key = SvPV(ST(i), klen);')
           ->if('klen == 2 && strncmp(key, "fd", 2) == 0')
             ->line('fd = SvIV(ST(i + 1));')
           ->endif
           ->if('klen == 8 && strncmp(key, "protocol", 8) == 0')
-            ->line('STRLEN plen;')
-            ->line('const char* proto = SvPV(ST(i + 1), plen);')
+            ->line('proto = SvPV(ST(i + 1), plen);')
             ->if('plen == 5 && strncmp(proto, "http2", 5) == 0')
               ->line('http2 = 1;')
             ->endif
@@ -199,8 +203,8 @@ sub gen_xs_new {
       ->line('stream_reset(fd);')
       ->line('stream_registry[fd].http2 = http2;')
       ->blank
-      ->line('SV* fd_sv = newSViv(fd);')
-      ->line('SV* ref = newRV_noinc(fd_sv);')
+      ->line('fd_sv = newSViv(fd);')
+      ->line('ref = newRV_noinc(fd_sv);')
       ->line('sv_bless(ref, gv_stashpv("Hypersonic::Stream", GV_ADD));')
       ->line('ST(0) = sv_2mortal(ref);')
       ->line('XSRETURN(1);')
