@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # JIT-compiled TLS/HTTPS support for Hypersonic
 # Uses OpenSSL for TLS support (via Alien::OpenSSL when available)
@@ -44,6 +44,7 @@ sub compile_tls_ops {
     my $module_name = 'Hypersonic::TLS::Ops_' . $MODULE_ID++;
 
     my $builder = XS::JIT::Builder->new;
+    my $inline = Hypersonic::JIT::Util->inline_keyword;
 
     # Add OpenSSL includes
     $builder->include('<openssl/ssl.h>')
@@ -67,8 +68,9 @@ sub compile_tls_ops {
 
     # Helper to get TLS connection
     $builder->line('')
-            ->line('static inline TLSConnection* get_tls_connection(int fd) {')
-            ->line('    for (int i = 0; i < MAX_TLS_CONNECTIONS; i++) {')
+            ->line("static $inline TLSConnection* get_tls_connection(int fd) {")
+            ->line('    int i;')
+            ->line('    for (i = 0; i < MAX_TLS_CONNECTIONS; i++) {')
             ->line('        if (g_tls_connections[i].fd == fd) {')
             ->line('            return &g_tls_connections[i];')
             ->line('        }')
@@ -78,8 +80,9 @@ sub compile_tls_ops {
 
     # Helper to allocate TLS connection
     $builder->line('')
-            ->line('static inline TLSConnection* alloc_tls_connection(int fd, SSL* ssl) {')
-            ->line('    for (int i = 0; i < MAX_TLS_CONNECTIONS; i++) {')
+            ->line("static $inline TLSConnection* alloc_tls_connection(int fd, SSL* ssl) {")
+            ->line('    int i;')
+            ->line('    for (i = 0; i < MAX_TLS_CONNECTIONS; i++) {')
             ->line('        if (g_tls_connections[i].fd == 0) {')
             ->line('            g_tls_connections[i].fd = fd;')
             ->line('            g_tls_connections[i].ssl = ssl;')
@@ -93,8 +96,9 @@ sub compile_tls_ops {
 
     # Helper to free TLS connection
     $builder->line('')
-            ->line('static inline void free_tls_connection(int fd) {')
-            ->line('    for (int i = 0; i < MAX_TLS_CONNECTIONS; i++) {')
+            ->line("static $inline void free_tls_connection(int fd) {")
+            ->line('    int i;')
+            ->line('    for (i = 0; i < MAX_TLS_CONNECTIONS; i++) {')
             ->line('        if (g_tls_connections[i].fd == fd) {')
             ->line('            if (g_tls_connections[i].ssl) {')
             ->line('                SSL_shutdown(g_tls_connections[i].ssl);')
@@ -239,13 +243,16 @@ sub compile_tls_ops {
     # XS wrapper for init_ssl_ctx
     $builder->xs_function('jit_init_ssl_ctx')
       ->xs_preamble
+      ->line('STRLEN cert_len, key_len;')
+      ->line('const char* cert_file;')
+      ->line('const char* key_file;')
+      ->line('int result;')
       ->line('if (items != 2) {')
       ->line('    croak("init_ssl_ctx requires cert_file and key_file");')
       ->line('}')
-      ->line('STRLEN cert_len, key_len;')
-      ->line('const char* cert_file = SvPV(ST(0), cert_len);')
-      ->line('const char* key_file = SvPV(ST(1), key_len);')
-      ->line('int result = init_ssl_ctx(cert_file, key_file);')
+      ->line('cert_file = SvPV(ST(0), cert_len);')
+      ->line('key_file = SvPV(ST(1), key_len);')
+      ->line('result = init_ssl_ctx(cert_file, key_file);')
       ->line('ST(0) = sv_2mortal(newSViv(result));')
       ->xs_return('1')
       ->xs_end;
@@ -253,11 +260,13 @@ sub compile_tls_ops {
     # XS wrapper for tls_accept
     $builder->xs_function('jit_tls_accept')
       ->xs_preamble
+      ->line('int client_fd;')
+      ->line('int result;')
       ->line('if (items != 1) {')
       ->line('    croak("tls_accept requires client_fd");')
       ->line('}')
-      ->line('int client_fd = SvIV(ST(0));')
-      ->line('int result = tls_accept(client_fd);')
+      ->line('client_fd = SvIV(ST(0));')
+      ->line('result = tls_accept(client_fd);')
       ->line('ST(0) = sv_2mortal(newSViv(result));')
       ->xs_return('1')
       ->xs_end;
@@ -265,10 +274,11 @@ sub compile_tls_ops {
     # XS wrapper for tls_close
     $builder->xs_function('jit_tls_close')
       ->xs_preamble
+      ->line('int fd;')
       ->line('if (items != 1) {')
       ->line('    croak("tls_close requires fd");')
       ->line('}')
-      ->line('int fd = SvIV(ST(0));')
+      ->line('fd = SvIV(ST(0));')
       ->line('tls_close(fd);')
       ->xs_return('0')
       ->xs_end;
@@ -304,7 +314,8 @@ C
 sub gen_ssl_ctx_init {
     my (%opts) = @_;
     my $enable_http2 = $opts{http2} // 0;
-    
+    my $inline = Hypersonic::JIT::Util->inline_keyword;
+
     my $alpn_code = '';
     if ($enable_http2) {
         $alpn_code = <<'ALPN';
@@ -359,8 +370,9 @@ typedef struct {
 #define MAX_TLS_CONNECTIONS 10000
 static TLSConnection g_tls_connections[MAX_TLS_CONNECTIONS];
 $alpn_code
-static inline TLSConnection* get_tls_connection(int fd) {
-    for (int i = 0; i < MAX_TLS_CONNECTIONS; i++) {
+static $inline TLSConnection* get_tls_connection(int fd) {
+    int i;
+    for (i = 0; i < MAX_TLS_CONNECTIONS; i++) {
         if (g_tls_connections[i].fd == fd) {
             return &g_tls_connections[i];
         }
@@ -368,8 +380,9 @@ static inline TLSConnection* get_tls_connection(int fd) {
     return NULL;
 }
 
-static inline TLSConnection* alloc_tls_connection(int fd, SSL* ssl) {
-    for (int i = 0; i < MAX_TLS_CONNECTIONS; i++) {
+static $inline TLSConnection* alloc_tls_connection(int fd, SSL* ssl) {
+    int i;
+    for (i = 0; i < MAX_TLS_CONNECTIONS; i++) {
         if (g_tls_connections[i].fd == 0) {
             g_tls_connections[i].fd = fd;
             g_tls_connections[i].ssl = ssl;
@@ -382,8 +395,9 @@ static inline TLSConnection* alloc_tls_connection(int fd, SSL* ssl) {
     return NULL;
 }
 
-static inline void free_tls_connection(int fd) {
-    for (int i = 0; i < MAX_TLS_CONNECTIONS; i++) {
+static $inline void free_tls_connection(int fd) {
+    int i;
+    for (i = 0; i < MAX_TLS_CONNECTIONS; i++) {
         if (g_tls_connections[i].fd == fd) {
             if (g_tls_connections[i].ssl) {
                 SSL_shutdown(g_tls_connections[i].ssl);
@@ -397,7 +411,7 @@ static inline void free_tls_connection(int fd) {
 }
 
 /* Check negotiated protocol after TLS handshake */
-static inline int get_negotiated_protocol(TLSConnection* conn) {
+static $inline int get_negotiated_protocol(TLSConnection* conn) {
     const unsigned char* alpn = NULL;
     unsigned int alpn_len = 0;
     SSL_get0_alpn_selected(conn->ssl, &alpn, &alpn_len);
