@@ -5,7 +5,7 @@ use warnings;
 use 5.010;
 use Carp;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use XS::JIT::Builder;
 
@@ -220,8 +220,9 @@ sub gen_ua_registry {
       ->blank
       ->comment('Get a pooled connection if available')
       ->line('static int pool_get(const char *host, int port) {')
+      ->line('    int i;')
       ->line('    time_t now = time(NULL);')
-      ->line('    for (int i = 0; i < CONN_POOL_SIZE; i++) {')
+      ->line('    for (i = 0; i < CONN_POOL_SIZE; i++) {')
       ->line('        if (conn_pool[i].fd > 0 && conn_pool[i].port == port &&')
       ->line('            strcmp(conn_pool[i].host, host) == 0 && conn_pool[i].expires > now) {')
       ->line('            int fd = conn_pool[i].fd;')
@@ -234,9 +235,10 @@ sub gen_ua_registry {
       ->blank
       ->comment('Return connection to pool (15 second keep-alive)')
       ->line('static void pool_put(int fd, const char *host, int port) {')
+      ->line('    int i;')
       ->line('    time_t now = time(NULL);')
-      ->line('    // Find empty slot or expired entry')
-      ->line('    for (int i = 0; i < CONN_POOL_SIZE; i++) {')
+      ->line('    /* Find empty slot or expired entry */')
+      ->line('    for (i = 0; i < CONN_POOL_SIZE; i++) {')
       ->line('        if (conn_pool[i].fd <= 0 || conn_pool[i].expires <= now) {')
       ->line('            if (conn_pool[i].fd > 0) close(conn_pool[i].fd);')
       ->line('            conn_pool[i].fd = fd;')
@@ -247,7 +249,7 @@ sub gen_ua_registry {
       ->line('            return;')
       ->line('        }')
       ->line('    }')
-      ->line('    // Pool full, just close')
+      ->line('    /* Pool full, just close */')
       ->line('    close(fd);')
       ->line('}')
       ->blank
@@ -275,20 +277,23 @@ sub gen_ua_registry {
       ->blank
       ->comment('Lookup DNS with caching (60 second TTL)')
       ->line('static int dns_lookup_cached(const char *host, struct in_addr *addr_out) {')
+      ->line('    int i;')
+      ->line('    int slot;')
+      ->line('    struct hostent *he;')
       ->line('    time_t now = time(NULL);')
-      ->line('    // Check cache')
-      ->line('    for (int i = 0; i < DNS_CACHE_SIZE; i++) {')
+      ->line('    /* Check cache */')
+      ->line('    for (i = 0; i < DNS_CACHE_SIZE; i++) {')
       ->line('        if (dns_cache[i].host[0] && strcmp(dns_cache[i].host, host) == 0 && dns_cache[i].expires > now) {')
       ->line('            *addr_out = dns_cache[i].addr;')
       ->line('            return 1;')
       ->line('        }')
       ->line('    }')
-      ->line('    // Cache miss - do lookup')
-      ->line('    struct hostent *he = gethostbyname(host);')
+      ->line('    /* Cache miss - do lookup */')
+      ->line('    he = gethostbyname(host);')
       ->line('    if (!he) return 0;')
       ->line('    memcpy(addr_out, he->h_addr_list[0], sizeof(struct in_addr));')
-      ->line('    // Store in cache')
-      ->line('    int slot = dns_cache_next++ % DNS_CACHE_SIZE;')
+      ->line('    /* Store in cache */')
+      ->line('    slot = dns_cache_next++ % DNS_CACHE_SIZE;')
       ->line('    strncpy(dns_cache[slot].host, host, 255);')
       ->line('    dns_cache[slot].host[255] = 0;')
       ->line('    dns_cache[slot].addr = *addr_out;')
@@ -309,7 +314,8 @@ sub gen_ua_registry {
       ->line("static UAContext ua_registry[UA_MAX_INSTANCES];")
       ->blank
       ->line('static int ua_alloc_slot(void) {')
-      ->line('    for (int i = 0; i < UA_MAX_INSTANCES; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < UA_MAX_INSTANCES; i++) {')
       ->line('        if (!ua_registry[i].in_use) {')
       ->line('            memset(&ua_registry[i], 0, sizeof(UAContext));')
       ->line('            ua_registry[i].in_use = 1;')
@@ -333,12 +339,21 @@ sub gen_xs_new {
     $builder->comment('Constructor: new() or new({ timeout => 30000, ... })')
       ->xs_function('xs_ua_new')
       ->xs_preamble
+      ->line('HV *opts;')
+      ->line('SV **val;')
+      ->line('STRLEN len;')
+      ->line('const char *url;')
+      ->line('int slot;')
+      ->line('UAContext *ctx;')
+      ->line('AV *self;')
+      ->line('SV *self_ref;')
+      ->blank
       ->line('if (items < 1) croak("Usage: Hypersonic::UA->new([$opts])");')
       ->blank
-      ->line('int slot = ua_alloc_slot();')
+      ->line('slot = ua_alloc_slot();')
       ->line('if (slot < 0) croak("Too many UA instances");')
       ->blank
-      ->line('UAContext *ctx = &ua_registry[slot];')
+      ->line('ctx = &ua_registry[slot];')
       ->blank
       ->comment('Defaults')
       ->line('ctx->timeout_ms = 30000;')
@@ -350,8 +365,7 @@ sub gen_xs_new {
       ->blank
       ->comment('Parse options hash if provided')
       ->if('items >= 2 && SvROK(ST(1)) && SvTYPE(SvRV(ST(1))) == SVt_PVHV')
-        ->line('HV *opts = (HV *)SvRV(ST(1));')
-        ->line('SV **val;')
+        ->line('opts = (HV *)SvRV(ST(1));')
         ->blank
         ->line('if ((val = hv_fetchs(opts, "timeout", 0)) && SvOK(*val)) ctx->timeout_ms = SvIV(*val);')
         ->line('if ((val = hv_fetchs(opts, "connect_timeout", 0)) && SvOK(*val)) ctx->connect_timeout_ms = SvIV(*val);')
@@ -359,15 +373,14 @@ sub gen_xs_new {
         ->line('if ((val = hv_fetchs(opts, "keep_alive", 0)) && SvOK(*val)) ctx->keep_alive = SvTRUE(*val) ? 1 : 0;')
         ->line('if ((val = hv_fetchs(opts, "headers", 0)) && SvROK(*val)) ctx->default_headers = SvREFCNT_inc(*val);')
         ->if('(val = hv_fetchs(opts, "base_url", 0)) && SvOK(*val)')
-          ->line('STRLEN len;')
-          ->line('const char *url = SvPV(*val, len);')
+          ->line('url = SvPV(*val, len);')
           ->line('ctx->base_url = (char *)malloc(len + 1);')
           ->line('memcpy(ctx->base_url, url, len + 1);')
         ->endif
       ->endif
       ->blank
       ->comment('Build array-based object')
-      ->line('AV *self = newAV();')
+      ->line('self = newAV();')
       ->line('av_extend(self, 6);')
       ->line('av_store(self, 0, newSViv(slot));')
       ->line('av_store(self, 1, newSViv(ctx->timeout_ms));')
@@ -377,7 +390,7 @@ sub gen_xs_new {
       ->line('av_store(self, 5, newSViv(ctx->max_redirects));')
       ->line('av_store(self, 6, newSViv(ctx->keep_alive));')
       ->blank
-      ->line('SV *self_ref = newRV_noinc((SV *)self);')
+      ->line('self_ref = newRV_noinc((SV *)self);')
       ->line('sv_bless(self_ref, gv_stashpv("Hypersonic::UA", GV_ADD));')
       ->blank
       ->line('ST(0) = sv_2mortal(self_ref);')
@@ -674,7 +687,7 @@ sub gen_xs_get {
       ->line('    char *hdr_end = strstr(resp_buf, "\\r\\n\\r\\n");')
       ->line('    if (hdr_end) {')
       ->line('        headers_end = hdr_end - resp_buf + 4;')
-      ->line('        // Parse Content-Length')
+      ->line('        /* Parse Content-Length */')
       ->line('        char *cl = strcasestr(resp_buf, "Content-Length:");')
       ->line('        if (cl && cl < hdr_end) content_length = atoi(cl + 15);')
       ->line('    }')
@@ -1529,13 +1542,14 @@ sub gen_xs_parallel {
     $builder->comment('Run multiple requests in parallel, wait for all')
       ->xs_function('xs_ua_parallel')
       ->xs_preamble
+      ->line('int i;')
       ->line('if (items < 2) croak("Usage: $ua->parallel(@futures)");')
       ->blank
       ->line('SV *self_sv = ST(0);')
       ->blank
       ->comment('Collect futures')
       ->line('AV *futures = newAV();')
-      ->line('for (int i = 1; i < items; i++) {')
+      ->line('for (i = 1; i < items; i++) {')
       ->line('    av_push(futures, SvREFCNT_inc(ST(i)));')
       ->line('}')
       ->blank
@@ -1543,7 +1557,7 @@ sub gen_xs_parallel {
       ->line('SPAGAIN;')
       ->line('ENTER; SAVETMPS;')
       ->line('PUSHMARK(SP);')
-      ->line('for (int i = 0; i <= av_len(futures); i++) {')
+      ->line('for (i = 0; i <= av_len(futures); i++) {')
       ->line('    SV **f = av_fetch(futures, i, 0);')
       ->line('    if (f && *f) XPUSHs(*f);')
       ->line('}')
@@ -1592,13 +1606,14 @@ sub gen_xs_race {
     $builder->comment('Run multiple requests in parallel, return first to complete')
       ->xs_function('xs_ua_race')
       ->xs_preamble
+      ->line('int i;')
       ->line('if (items < 2) croak("Usage: $ua->race(@futures)");')
       ->blank
       ->line('SV *self_sv = ST(0);')
       ->blank
       ->comment('Collect futures')
       ->line('AV *futures = newAV();')
-      ->line('for (int i = 1; i < items; i++) {')
+      ->line('for (i = 1; i < items; i++) {')
       ->line('    av_push(futures, SvREFCNT_inc(ST(i)));')
       ->line('}')
       ->blank
@@ -1606,7 +1621,7 @@ sub gen_xs_race {
       ->line('SPAGAIN;')
       ->line('ENTER; SAVETMPS;')
       ->line('PUSHMARK(SP);')
-      ->line('for (int i = 0; i <= av_len(futures); i++) {')
+      ->line('for (i = 0; i <= av_len(futures); i++) {')
       ->line('    SV **f = av_fetch(futures, i, 0);')
       ->line('    if (f && *f) XPUSHs(*f);')
       ->line('}')
