@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # Use Hypersonic::Event for backend detection
 use Hypersonic::Event;
@@ -151,8 +151,9 @@ sub gen_async_context_registry {
       ->blank
       ->comment('Get a pooled connection')
       ->line('static int async_pool_get(const char *host, int port) {')
+      ->line('    int i;')
       ->line('    time_t now = time(NULL);')
-      ->line('    for (int i = 0; i < ASYNC_POOL_SIZE; i++) {')
+      ->line('    for (i = 0; i < ASYNC_POOL_SIZE; i++) {')
       ->line('        if (async_conn_pool[i].fd > 0 && async_conn_pool[i].port == port &&')
       ->line('            strcmp(async_conn_pool[i].host, host) == 0 && async_conn_pool[i].expires > now) {')
       ->line('            int fd = async_conn_pool[i].fd;')
@@ -165,9 +166,10 @@ sub gen_async_context_registry {
       ->blank
       ->comment('Return connection to pool (10 second keep-alive)')
       ->line('static void async_pool_put(int fd, const char *host, int port) {')
+      ->line('    int i;')
       ->line('    if (fd < 0) return;')
       ->line('    time_t now = time(NULL);')
-      ->line('    for (int i = 0; i < ASYNC_POOL_SIZE; i++) {')
+      ->line('    for (i = 0; i < ASYNC_POOL_SIZE; i++) {')
       ->line('        if (async_conn_pool[i].fd <= 0 || async_conn_pool[i].expires <= now) {')
       ->line('            if (async_conn_pool[i].fd > 0) close(async_conn_pool[i].fd);')
       ->line('            async_conn_pool[i].fd = fd;')
@@ -182,7 +184,8 @@ sub gen_async_context_registry {
       ->line('}')
       ->blank
       ->line('static int async_alloc_slot(void) {')
-      ->line('    for (int i = 0; i < MAX_ASYNC_CONTEXTS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < MAX_ASYNC_CONTEXTS; i++) {')
       ->line('        if (!async_registry[i].in_use) {')
       ->line('            memset(&async_registry[i], 0, sizeof(AsyncContext));')
       ->line('            async_registry[i].in_use = 1;')
@@ -346,19 +349,31 @@ sub gen_async_advance_state {
 
 sub gen_xs_poll_batch {
     my ($class, $builder, $opts) = @_;
-    
+
     my $event_backend = $opts->{event_backend};
     my $backend_name = $opts->{event_backend_name};
-    
+
+    # Check if this backend supports the slot API (kqueue, epoll)
+    my $use_advanced = $backend_name =~ /^(kqueue|epoll)$/;
+
     $builder->comment("Batch poll all pending slots using $backend_name")
       ->xs_function('xs_async_poll_batch')
       ->xs_preamble
-      ->line('if (items < 1) croak("Usage: poll_batch(@slots)");')
+      ->line('int i;')
+      ->line('int slot_count;')
+      ->line('int registered;')
+      ->line('int nev;')
+      ->line('AV *ready;');
+
+    # Add event struct declaration for advanced backends (C89 compliance)
+    if ($use_advanced) {
+        my $event_struct = $event_backend->event_struct;
+        $builder->line("struct $event_struct events[MAX_EVENTS];");
+    }
+
+    $builder->line('if (items < 1) croak("Usage: poll_batch(@slots)");')
       ->blank;
     
-    # Check if this backend supports the slot API (kqueue, epoll)
-    my $use_advanced = $backend_name =~ /^(kqueue|epoll)$/;
-    
     if ($use_advanced) {
         # Create event loop if needed
         $builder->comment('Create event loop if not exists')
@@ -372,10 +387,10 @@ sub gen_xs_poll_batch {
         
         # Collect slots and register with event loop
         $builder->comment('Collect all pending slots and register with event loop')
-          ->line('int slot_count = items;')
-          ->line('int registered = 0;')
+          ->line('slot_count = items;')
+          ->line('registered = 0;')
           ->blank
-          ->line('for (int i = 0; i < slot_count; i++) {')
+          ->line('for (i = 0; i < slot_count; i++) {')
           ->line('    int slot = SvIV(ST(i));')
           ->line('    if (slot < 0 || slot >= MAX_ASYNC_CONTEXTS) continue;')
           ->line('    AsyncContext *ctx = &async_registry[slot];')
@@ -395,10 +410,8 @@ sub gen_xs_poll_batch {
           ->line('}')
           ->blank;
         
-        # Wait for events
-        my $event_struct = $event_backend->event_struct;
-        $builder->comment('Wait for events (short timeout for responsiveness)')
-          ->line("struct $event_struct events[MAX_EVENTS];");
+        # Wait for events (events array already declared at top for C89 compliance)
+        $builder->comment('Wait for events (short timeout for responsiveness)');
         
         # Use gen_wait_once (no loop control statements)
         $event_backend->gen_wait_once($builder, 'async_ev_fd', 'events', 'nev', '1');  # 1ms timeout
@@ -406,8 +419,8 @@ sub gen_xs_poll_batch {
         # Process ready events
         $builder->blank
           ->comment('Process ready events')
-          ->line('AV *ready = newAV();')
-          ->line('for (int i = 0; i < nev; i++) {');
+          ->line('ready = newAV();')
+          ->line('for (i = 0; i < nev; i++) {');
         
         # Get slot from event
         $event_backend->gen_get_slot($builder, 'events', 'i', 'slot');
@@ -428,7 +441,7 @@ sub gen_xs_poll_batch {
         # Fallback to select-based implementation for other backends
         $builder->comment('Fallback to select() for portability')
           ->line('AV *ready = newAV();')
-          ->line('for (int i = 0; i < items; i++) {')
+          ->line('for (i = 0; i < items; i++) {')
           ->line('    int slot = SvIV(ST(i));')
           ->line('    if (slot < 0 || slot >= MAX_ASYNC_CONTEXTS) continue;')
           ->line('    AsyncContext *ctx = &async_registry[slot];')
@@ -816,6 +829,9 @@ sub gen_xs_tick {
       ->comment('Loops until all requests complete OR no progress for 1ms')
       ->xs_function('xs_ua_tick')
       ->xs_preamble
+      ->line('int i;')
+      ->line('int nev;')
+      ->line('I32 j;')
       ->line('if (items < 1) croak("Usage: $ua->tick()");')
       ->blank
       ->line('SV *self_sv = ST(0);')
@@ -847,8 +863,8 @@ sub gen_xs_tick {
       ->line('    int slots[MAX_ASYNC_CONTEXTS];')
       ->line('    int slot_count = 0;')
       ->blank
-      ->line('    for (I32 i = 0; i < len; i++) {')
-      ->line('        SV **slot_svp = av_fetch(pending_av, i, 0);')
+      ->line('    for (j = 0; j < len; j++) {')
+      ->line('        SV **slot_svp = av_fetch(pending_av, j, 0);')
       ->line('        if (!slot_svp) continue;')
       ->line('        int slot = SvIV(*slot_svp);')
       ->line('        if (slot >= 0 && slot < MAX_ASYNC_CONTEXTS) {')
@@ -873,7 +889,7 @@ sub gen_xs_tick {
     $builder->comment('Register all fds with event loop')
       ->line('int change_count = 0;')
       ->blank
-      ->line('for (int i = 0; i < slot_count; i++) {')
+      ->line('for (i = 0; i < slot_count; i++) {')
       ->line('    int slot = slots[i];')
       ->line('    AsyncContext *ctx = &async_registry[slot];')
       ->line('    int events = async_poll_one(slot);')
@@ -896,7 +912,7 @@ sub gen_xs_tick {
     # Process ready events
     $builder->blank
       ->comment('Process ready events in pure C')
-      ->line('for (int i = 0; i < nev; i++) {');
+      ->line('for (i = 0; i < nev; i++) {');
     $event_backend->gen_get_slot($builder, 'ready_events', 'i', 'slot');
     $builder->line('    if (slot >= 0 && slot < MAX_ASYNC_CONTEXTS) {')
       ->line('        async_advance_state(slot);')
@@ -905,8 +921,8 @@ sub gen_xs_tick {
       ->blank
       ->comment('Check for completed slots and resolve futures')
       ->line('int completed = 0;')
-      ->line('for (I32 i = len - 1; i >= 0; i--) {')
-      ->line('    SV **slot_svp = av_fetch(pending_av, i, 0);')
+      ->line('for (j = len - 1; j >= 0; j--) {')
+      ->line('    SV **slot_svp = av_fetch(pending_av, j, 0);')
       ->line('    if (!slot_svp) continue;')
       ->line('    int slot = SvIV(*slot_svp);')
       ->line('    if (slot < 0 || slot >= MAX_ASYNC_CONTEXTS) continue;')
