@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant {
     MAX_H2_SESSIONS        => 100,
@@ -110,7 +110,8 @@ sub gen_h2_registry {
 
     # Helper: find session by fd
     $builder->line('static H2Session* h2_find_session(int fd) {')
-      ->line('    for (int i = 0; i < MAX_H2_SESSIONS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < MAX_H2_SESSIONS; i++) {')
       ->line('        if (h2_registry[i].fd == fd) {')
       ->line('            return &h2_registry[i];')
       ->line('        }')
@@ -129,7 +130,8 @@ sub gen_h2_registry {
 
     # Helper: allocate session slot
     $builder->line('static int h2_alloc_session(int fd) {')
-      ->line('    for (int i = 0; i < MAX_H2_SESSIONS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < MAX_H2_SESSIONS; i++) {')
       ->line('        if (h2_registry[i].fd == 0) {')
       ->line('            memset(&h2_registry[i], 0, sizeof(H2Session));')
       ->line('            h2_registry[i].fd = fd;')
@@ -142,7 +144,8 @@ sub gen_h2_registry {
 
     # Helper: find stream in session
     $builder->line('static H2Stream* h2_find_stream(H2Session* sess, int32_t stream_id) {')
-      ->line('    for (int i = 0; i < sess->stream_count; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < sess->stream_count; i++) {')
       ->line('        if (sess->streams[i].stream_id == stream_id) {')
       ->line('            return &sess->streams[i];')
       ->line('        }')
@@ -255,18 +258,23 @@ sub gen_xs_session_new {
     $builder->comment('Create HTTP/2 client session')
       ->xs_function('xs_h2_session_new')
       ->xs_preamble
-      ->line('if (items != 1) croak("Usage: session_new(fd)");')
-      ->line('int fd = (int)SvIV(ST(0));')
+      ->line('int fd;')
+      ->line('int slot;')
+      ->line('H2Session* h2sess;')
+      ->line('nghttp2_session_callbacks* callbacks;')
+      ->line('nghttp2_settings_entry iv[1];')
       ->blank
-      ->line('int slot = h2_alloc_session(fd);')
+      ->line('if (items != 1) croak("Usage: session_new(fd)");')
+      ->line('fd = (int)SvIV(ST(0));')
+      ->blank
+      ->line('slot = h2_alloc_session(fd);')
       ->line('if (slot < 0) {')
       ->line('    ST(0) = sv_2mortal(newSViv(-1));')
       ->line('    XSRETURN(1);')
       ->line('}')
       ->blank
-      ->line('H2Session* h2sess = &h2_registry[slot];')
+      ->line('h2sess = &h2_registry[slot];')
       ->blank
-      ->line('nghttp2_session_callbacks* callbacks;')
       ->line('nghttp2_session_callbacks_new(&callbacks);')
       ->line('nghttp2_session_callbacks_set_send_callback(callbacks, h2_send_cb);')
       ->line('nghttp2_session_callbacks_set_recv_callback(callbacks, h2_recv_cb);')
@@ -277,9 +285,8 @@ sub gen_xs_session_new {
       ->line('nghttp2_session_client_new(&h2sess->session, callbacks, h2sess);')
       ->line('nghttp2_session_callbacks_del(callbacks);')
       ->blank
-      ->line('nghttp2_settings_entry iv[1] = {')
-      ->line('    {NGHTTP2_SETTINGS_MAX_CONCURRENT_STREAMS, 100}')
-      ->line('};')
+      ->line('iv[0].settings_id = NGHTTP2_SETTINGS_MAX_CONCURRENT_STREAMS;')
+      ->line('iv[0].value = 100;')
       ->line('nghttp2_submit_settings(h2sess->session, NGHTTP2_FLAG_NONE, iv, 1);')
       ->line('nghttp2_session_send(h2sess->session);')
       ->blank
@@ -295,36 +302,61 @@ sub gen_xs_submit_request {
     $builder->comment('Submit HTTP/2 request')
       ->xs_function('xs_h2_submit_request')
       ->xs_preamble
+      ->line('int slot;')
+      ->line('STRLEN method_len, scheme_len, auth_len, path_len;')
+      ->line('const char* method;')
+      ->line('const char* scheme;')
+      ->line('const char* authority;')
+      ->line('const char* path;')
+      ->line('H2Session* h2sess;')
+      ->line('nghttp2_nv hdrs[4];')
+      ->line('int32_t stream_id;')
+      ->line('int idx;')
+      ->line('H2Stream* st;')
+      ->blank
       ->line('if (items < 5) croak("Usage: submit_request(session_slot, method, scheme, authority, path)");')
       ->blank
-      ->line('int slot = (int)SvIV(ST(0));')
-      ->line('STRLEN method_len, scheme_len, auth_len, path_len;')
-      ->line('const char* method = SvPV(ST(1), method_len);')
-      ->line('const char* scheme = SvPV(ST(2), scheme_len);')
-      ->line('const char* authority = SvPV(ST(3), auth_len);')
-      ->line('const char* path = SvPV(ST(4), path_len);')
+      ->line('slot = (int)SvIV(ST(0));')
+      ->line('method = SvPV(ST(1), method_len);')
+      ->line('scheme = SvPV(ST(2), scheme_len);')
+      ->line('authority = SvPV(ST(3), auth_len);')
+      ->line('path = SvPV(ST(4), path_len);')
       ->blank
-      ->line('H2Session* h2sess = h2_get_session(slot);')
+      ->line('h2sess = h2_get_session(slot);')
       ->line('if (!h2sess) {')
       ->line('    ST(0) = sv_2mortal(newSViv(-1));')
       ->line('    XSRETURN(1);')
       ->line('}')
       ->blank
-      ->line('nghttp2_nv hdrs[4] = {')
-      ->line('    {(uint8_t*)":method", (uint8_t*)method, 7, method_len, NGHTTP2_NV_FLAG_NONE},')
-      ->line('    {(uint8_t*)":scheme", (uint8_t*)scheme, 7, scheme_len, NGHTTP2_NV_FLAG_NONE},')
-      ->line('    {(uint8_t*)":authority", (uint8_t*)authority, 10, auth_len, NGHTTP2_NV_FLAG_NONE},')
-      ->line('    {(uint8_t*)":path", (uint8_t*)path, 5, path_len, NGHTTP2_NV_FLAG_NONE},')
-      ->line('};')
+      ->line('hdrs[0].name = (uint8_t*)":method";')
+      ->line('hdrs[0].value = (uint8_t*)method;')
+      ->line('hdrs[0].namelen = 7;')
+      ->line('hdrs[0].valuelen = method_len;')
+      ->line('hdrs[0].flags = NGHTTP2_NV_FLAG_NONE;')
+      ->line('hdrs[1].name = (uint8_t*)":scheme";')
+      ->line('hdrs[1].value = (uint8_t*)scheme;')
+      ->line('hdrs[1].namelen = 7;')
+      ->line('hdrs[1].valuelen = scheme_len;')
+      ->line('hdrs[1].flags = NGHTTP2_NV_FLAG_NONE;')
+      ->line('hdrs[2].name = (uint8_t*)":authority";')
+      ->line('hdrs[2].value = (uint8_t*)authority;')
+      ->line('hdrs[2].namelen = 10;')
+      ->line('hdrs[2].valuelen = auth_len;')
+      ->line('hdrs[2].flags = NGHTTP2_NV_FLAG_NONE;')
+      ->line('hdrs[3].name = (uint8_t*)":path";')
+      ->line('hdrs[3].value = (uint8_t*)path;')
+      ->line('hdrs[3].namelen = 5;')
+      ->line('hdrs[3].valuelen = path_len;')
+      ->line('hdrs[3].flags = NGHTTP2_NV_FLAG_NONE;')
       ->blank
-      ->line('int32_t stream_id = nghttp2_submit_request(h2sess->session, NULL, hdrs, 4, NULL, NULL);')
+      ->line('stream_id = nghttp2_submit_request(h2sess->session, NULL, hdrs, 4, NULL, NULL);')
       ->line('if (stream_id < 0) {')
       ->line('    ST(0) = sv_2mortal(newSViv(stream_id));')
       ->line('    XSRETURN(1);')
       ->line('}')
       ->blank
-      ->line('int idx = h2sess->stream_count++;')
-      ->line('H2Stream* st = &h2sess->streams[idx];')
+      ->line('idx = h2sess->stream_count++;')
+      ->line('st = &h2sess->streams[idx];')
       ->line('memset(st, 0, sizeof(H2Stream));')
       ->line('st->stream_id = stream_id;')
       ->line('st->body = malloc(4096);')
@@ -384,6 +416,7 @@ sub gen_xs_session_close {
     $builder->comment('Close HTTP/2 session')
       ->xs_function('xs_h2_session_close')
       ->xs_preamble
+      ->line('int i;')
       ->line('if (items != 1) croak("Usage: session_close(session_slot)");')
       ->blank
       ->line('int slot = (int)SvIV(ST(0));')
@@ -393,7 +426,7 @@ sub gen_xs_session_close {
       ->line('    XSRETURN(1);')
       ->line('}')
       ->blank
-      ->line('for (int i = 0; i < h2sess->stream_count; i++) {')
+      ->line('for (i = 0; i < h2sess->stream_count; i++) {')
       ->line('    H2Stream* st = &h2sess->streams[i];')
       ->line('    if (st->body) free(st->body);')
       ->line('    if (st->headers) SvREFCNT_dec((SV*)st->headers);')
