@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant {
     MAX_PER_HOST  => 6,
@@ -98,7 +98,8 @@ sub gen_pool_helpers {
 
     # Find bucket by host:port:tls
     $builder->line('static PoolBucket* pool_find_bucket(const char* host, uint16_t port, int tls) {')
-      ->line('    for (int i = 0; i < g_pool.bucket_count; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < g_pool.bucket_count; i++) {')
       ->line('        PoolBucket* b = &g_pool.buckets[i];')
       ->line('        if (b->port == port && b->tls == tls && strcasecmp(b->host, host) == 0) {')
       ->line('            return b;')
@@ -162,11 +163,15 @@ sub gen_xs_init {
     $builder->comment('Initialize connection pool')
       ->xs_function('xs_pool_init')
       ->xs_preamble
+      ->line('int max_per_host;')
+      ->line('int max_total;')
+      ->line('int idle_timeout;')
+      ->blank
       ->line('if (items > 3) croak("Usage: init([max_per_host], [max_total], [idle_timeout])");')
       ->blank
-      ->line('int max_per_host = (items > 0) ? SvIV(ST(0)) : 6;')
-      ->line('int max_total = (items > 1) ? SvIV(ST(1)) : 100;')
-      ->line('int idle_timeout = (items > 2) ? SvIV(ST(2)) : 60;')
+      ->line('max_per_host = (items > 0) ? SvIV(ST(0)) : 6;')
+      ->line('max_total = (items > 1) ? SvIV(ST(1)) : 100;')
+      ->line('idle_timeout = (items > 2) ? SvIV(ST(2)) : 60;')
       ->blank
       ->line('memset(&g_pool, 0, sizeof(g_pool));')
       ->line('g_pool.max_per_host = max_per_host;')
@@ -185,22 +190,29 @@ sub gen_xs_get {
     $builder->comment('Get connection from pool')
       ->xs_function('xs_pool_get')
       ->xs_preamble
+      ->line('const char* host;')
+      ->line('uint16_t port;')
+      ->line('int tls;')
+      ->line('PoolBucket* b;')
+      ->line('int i;')
+      ->line('time_t now;')
+      ->blank
       ->line('if (items != 3) croak("Usage: get(host, port, tls)");')
       ->blank
-      ->line('const char* host = SvPV_nolen(ST(0));')
-      ->line('uint16_t port = (uint16_t)SvIV(ST(1));')
-      ->line('int tls = SvIV(ST(2));')
+      ->line('host = SvPV_nolen(ST(0));')
+      ->line('port = (uint16_t)SvIV(ST(1));')
+      ->line('tls = SvIV(ST(2));')
       ->blank
-      ->line('PoolBucket* b = pool_find_bucket(host, port, tls);')
+      ->line('b = pool_find_bucket(host, port, tls);')
       ->line('if (!b || b->count == 0) {')
       ->line('    g_pool.misses++;')
       ->line('    ST(0) = &PL_sv_undef;')
       ->line('    XSRETURN(1);')
       ->line('}')
       ->blank
-      ->line('time_t now = time(NULL);')
+      ->line('now = time(NULL);')
       ->blank
-      ->line('for (int i = 0; i < POOL_MAX_PER_HOST; i++) {')
+      ->line('for (i = 0; i < POOL_MAX_PER_HOST; i++) {')
       ->line('    PoolConn* c = &b->conns[i];')
       ->line('    if (c->fd <= 0 || c->in_use) continue;')
       ->blank
@@ -237,12 +249,19 @@ sub gen_xs_put {
     $builder->comment('Return connection to pool')
       ->xs_function('xs_pool_put')
       ->xs_preamble
+      ->line('const char* host;')
+      ->line('uint16_t port;')
+      ->line('int tls;')
+      ->line('int fd;')
+      ->line('PoolBucket* b;')
+      ->line('int i;')
+      ->blank
       ->line('if (items != 4) croak("Usage: put(host, port, tls, fd)");')
       ->blank
-      ->line('const char* host = SvPV_nolen(ST(0));')
-      ->line('uint16_t port = (uint16_t)SvIV(ST(1));')
-      ->line('int tls = SvIV(ST(2));')
-      ->line('int fd = SvIV(ST(3));')
+      ->line('host = SvPV_nolen(ST(0));')
+      ->line('port = (uint16_t)SvIV(ST(1));')
+      ->line('tls = SvIV(ST(2));')
+      ->line('fd = SvIV(ST(3));')
       ->blank
       ->line('if (g_pool.total_count >= g_pool.max_total) {')
       ->line('    close(fd);')
@@ -250,17 +269,16 @@ sub gen_xs_put {
       ->line('    XSRETURN(1);')
       ->line('}')
       ->blank
-      ->line('PoolBucket* b = pool_get_bucket(host, port, tls);')
+      ->line('b = pool_get_bucket(host, port, tls);')
       ->line('if (!b) {')
       ->line('    close(fd);')
       ->line('    ST(0) = sv_2mortal(newSViv(0));')
       ->line('    XSRETURN(1);')
       ->line('}')
-      ->blank
       ->line('if (b->count >= g_pool.max_per_host) {')
       ->line('    time_t oldest_time = time(NULL);')
       ->line('    int oldest_idx = -1;')
-      ->line('    for (int i = 0; i < POOL_MAX_PER_HOST; i++) {')
+      ->line('    for (i = 0; i < POOL_MAX_PER_HOST; i++) {')
       ->line('        if (b->conns[i].fd > 0 && !b->conns[i].in_use) {')
       ->line('            if (b->conns[i].last_used < oldest_time) {')
       ->line('                oldest_time = b->conns[i].last_used;')
@@ -275,7 +293,7 @@ sub gen_xs_put {
       ->line('    }')
       ->line('}')
       ->blank
-      ->line('for (int i = 0; i < POOL_MAX_PER_HOST; i++) {')
+      ->line('for (i = 0; i < POOL_MAX_PER_HOST; i++) {')
       ->line('    if (b->conns[i].fd <= 0) {')
       ->line('        b->conns[i].fd = fd;')
       ->line('        b->conns[i].tls = tls;')
@@ -301,20 +319,27 @@ sub gen_xs_remove {
     $builder->comment('Remove connection from pool')
       ->xs_function('xs_pool_remove')
       ->xs_preamble
+      ->line('const char* host;')
+      ->line('uint16_t port;')
+      ->line('int tls;')
+      ->line('int fd;')
+      ->line('int i;')
+      ->line('PoolBucket* b;')
+      ->blank
       ->line('if (items != 4) croak("Usage: remove(host, port, tls, fd)");')
       ->blank
-      ->line('const char* host = SvPV_nolen(ST(0));')
-      ->line('uint16_t port = (uint16_t)SvIV(ST(1));')
-      ->line('int tls = SvIV(ST(2));')
-      ->line('int fd = SvIV(ST(3));')
+      ->line('host = SvPV_nolen(ST(0));')
+      ->line('port = (uint16_t)SvIV(ST(1));')
+      ->line('tls = SvIV(ST(2));')
+      ->line('fd = SvIV(ST(3));')
       ->blank
-      ->line('PoolBucket* b = pool_find_bucket(host, port, tls);')
+      ->line('b = pool_find_bucket(host, port, tls);')
       ->line('if (!b) {')
       ->line('    ST(0) = sv_2mortal(newSViv(0));')
       ->line('    XSRETURN(1);')
       ->line('}')
       ->blank
-      ->line('for (int i = 0; i < POOL_MAX_PER_HOST; i++) {')
+      ->line('for (i = 0; i < POOL_MAX_PER_HOST; i++) {')
       ->line('    if (b->conns[i].fd == fd) {')
       ->line('        pool_close_conn(&b->conns[i]);')
       ->line('        b->count--;')
@@ -337,9 +362,10 @@ sub gen_xs_clear {
       ->xs_function('xs_pool_clear')
       ->xs_preamble
       ->blank
-      ->line('for (int i = 0; i < g_pool.bucket_count; i++) {')
+      ->line('int i, j;')
+      ->line('for (i = 0; i < g_pool.bucket_count; i++) {')
       ->line('    PoolBucket* b = &g_pool.buckets[i];')
-      ->line('    for (int j = 0; j < POOL_MAX_PER_HOST; j++) {')
+      ->line('    for (j = 0; j < POOL_MAX_PER_HOST; j++) {')
       ->line('        if (b->conns[j].fd > 0) {')
       ->line('            pool_close_conn(&b->conns[j]);')
       ->line('        }')
@@ -362,12 +388,13 @@ sub gen_xs_prune {
       ->xs_function('xs_pool_prune')
       ->xs_preamble
       ->blank
+      ->line('int i, j;')
       ->line('time_t now = time(NULL);')
       ->line('int pruned = 0;')
       ->blank
-      ->line('for (int i = 0; i < g_pool.bucket_count; i++) {')
+      ->line('for (i = 0; i < g_pool.bucket_count; i++) {')
       ->line('    PoolBucket* b = &g_pool.buckets[i];')
-      ->line('    for (int j = 0; j < POOL_MAX_PER_HOST; j++) {')
+      ->line('    for (j = 0; j < POOL_MAX_PER_HOST; j++) {')
       ->line('        PoolConn* c = &b->conns[j];')
       ->line('        if (c->fd > 0 && !c->in_use) {')
       ->line('            int age = now - c->last_used;')
