@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant MAX_HEADER_SIZE => 16384;
 use constant DECODE_BUF_SIZE => 1048576;
@@ -46,6 +46,7 @@ sub gen_helpers {
     $builder->comment('Parse HTTP/1.x response status line')
       ->comment('Returns: status code, or -1 on error')
       ->line('static int http1_parse_status_line(const char* buf, size_t len, int* http_minor) {')
+      ->line('    int i;')
       ->line('    if (len < 12) return -1;')
       ->line('    if (memcmp(buf, "HTTP/1.", 7) != 0) return -1;')
       ->blank
@@ -53,7 +54,7 @@ sub gen_helpers {
       ->line('    if (buf[8] != \' \') return -1;')
       ->blank
       ->line('    int status = 0;')
-      ->line('    for (int i = 9; i < 12; i++) {')
+      ->line('    for (i = 9; i < 12; i++) {')
       ->line('        if (buf[i] < \'0\' || buf[i] > \'9\') return -1;')
       ->line('        status = status * 10 + (buf[i] - \'0\');')
       ->line('    }')
@@ -99,9 +100,10 @@ sub gen_helpers {
       ->line('        const char* vend = value;')
       ->line('        while (vend < end && *vend != \'\\r\' && *vend != \'\\n\') vend++;')
       ->blank
+      ->line('        int i;')
       ->line('        char norm_name[256];')
       ->line('        if (name_len > 255) name_len = 255;')
-      ->line('        for (int i = 0; i < name_len; i++) {')
+      ->line('        for (i = 0; i < name_len; i++) {')
       ->line('            char c = p[i];')
       ->line('            if (c >= \'A\' && c <= \'Z\') c += 32;')
       ->line('            else if (c == \'-\') c = \'_\';')
