@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant {
     SLOT_STATUS         => 0,
@@ -133,19 +133,24 @@ sub gen_xs_new {
     $builder->comment('Create new response from parsed data')
       ->xs_function('xs_response_new')
       ->xs_preamble
+      ->line('int status;')
+      ->line('HV* opts;')
+      ->line('AV* self;')
+      ->line('SV** val;')
+      ->line('SV* obj;')
+      ->blank
       ->line('if (items < 2) croak("Usage: new(class, status, ...)");')
       ->blank
-      ->line('int status = (int)SvIV(ST(1));')
-      ->line('HV* opts = (items > 2 && SvROK(ST(2))) ? (HV*)SvRV(ST(2)) : NULL;')
+      ->line('status = (int)SvIV(ST(1));')
+      ->line('opts = (items > 2 && SvROK(ST(2))) ? (HV*)SvRV(ST(2)) : NULL;')
       ->blank
-      ->line('AV* self = newAV();')
+      ->line('self = newAV();')
       ->line('av_extend(self, RESP_SLOT_COUNT - 1);')
       ->blank
       ->line('av_store(self, RESP_SLOT_STATUS, newSViv(status));')
       ->line('av_store(self, RESP_SLOT_STATUS_TEXT, newSVpv(resp_status_text(status), 0));')
       ->blank
       ->if('opts')
-        ->line('SV** val;')
         ->line('val = hv_fetchs(opts, "headers", 0);')
         ->line('av_store(self, RESP_SLOT_HEADERS, val && *val ? newSVsv(*val) : newRV_noinc((SV*)newHV()));')
         ->line('val = hv_fetchs(opts, "body", 0);')
@@ -170,7 +175,7 @@ sub gen_xs_new {
       ->line('av_store(self, RESP_SLOT_TIMING, newRV_noinc((SV*)newHV()));')
       ->line('av_store(self, RESP_SLOT_JSON, &PL_sv_undef);')
       ->blank
-      ->line('SV* obj = sv_bless(newRV_noinc((SV*)self), gv_stashpv("Hypersonic::UA::Response", GV_ADD));')
+      ->line('obj = sv_bless(newRV_noinc((SV*)self), gv_stashpv("Hypersonic::UA::Response", GV_ADD));')
       ->line('ST(0) = sv_2mortal(obj);')
       ->xs_return('1')
       ->xs_end
@@ -183,35 +188,45 @@ sub gen_xs_from_raw {
     $builder->comment('Create response from raw HTTP response')
       ->xs_function('xs_response_from_raw')
       ->xs_preamble
-      ->line('if (items != 2) croak("Usage: from_raw(class, raw)");')
-      ->blank
       ->line('STRLEN raw_len;')
-      ->line('const char* raw = SvPV(ST(1), raw_len);')
-      ->blank
+      ->line('const char* raw;')
+      ->line('int http_minor;')
+      ->line('int status;')
+      ->line('const char* body_start;')
+      ->line('size_t headers_len;')
+      ->line('size_t body_len;')
+      ->line('HV* headers;')
+      ->line('AV* self;')
+      ->line('SV** ct;')
+      ->line('SV** cl;')
+      ->line('SV* obj;')
       ->comment('Parse using HTTP1 helpers (must be linked)')
       ->line('extern int http1_parse_status_line(const char*, size_t, int*);')
       ->line('extern const char* http1_find_body_start(const char*, size_t);')
       ->line('extern HV* http1_parse_headers_into_hv(const char*, size_t);')
       ->blank
-      ->line('int http_minor;')
-      ->line('int status = http1_parse_status_line(raw, raw_len, &http_minor);')
+      ->line('if (items != 2) croak("Usage: from_raw(class, raw)");')
+      ->blank
+      ->line('raw = SvPV(ST(1), raw_len);')
+      ->blank
+      ->line('status = http1_parse_status_line(raw, raw_len, &http_minor);')
       ->if('status < 0')
         ->line('ST(0) = &PL_sv_undef;')
         ->line('XSRETURN(1);')
       ->endif
       ->blank
-      ->line('const char* body_start = http1_find_body_start(raw, raw_len);')
+      ->line('body_start = http1_find_body_start(raw, raw_len);')
       ->if('!body_start')
         ->line('ST(0) = &PL_sv_undef;')
         ->line('XSRETURN(1);')
       ->endif
       ->blank
-      ->line('size_t headers_len = body_start - raw;')
-      ->line('size_t body_len = raw_len - headers_len;')
+      ->line('headers_len = body_start - raw;')
+      ->line('body_len = raw_len - headers_len;')
       ->blank
-      ->line('HV* headers = http1_parse_headers_into_hv(raw, headers_len);')
+      ->line('headers = http1_parse_headers_into_hv(raw, headers_len);')
       ->blank
-      ->line('AV* self = newAV();')
+      ->line('self = newAV();')
       ->line('av_extend(self, RESP_SLOT_COUNT - 1);')
       ->blank
       ->line('av_store(self, RESP_SLOT_STATUS, newSViv(status));')
@@ -219,10 +234,10 @@ sub gen_xs_from_raw {
       ->line('av_store(self, RESP_SLOT_HEADERS, newRV_noinc((SV*)headers));')
       ->line('av_store(self, RESP_SLOT_BODY, newSVpvn(body_start, body_len));')
       ->blank
-      ->line('SV** ct = hv_fetchs(headers, "content_type", 0);')
+      ->line('ct = hv_fetchs(headers, "content_type", 0);')
       ->line('av_store(self, RESP_SLOT_CONTENT_TYPE, ct && *ct ? newSVsv(*ct) : newSVpvn("", 0));')
       ->blank
-      ->line('SV** cl = hv_fetchs(headers, "content_length", 0);')
+      ->line('cl = hv_fetchs(headers, "content_length", 0);')
       ->line('av_store(self, RESP_SLOT_CONTENT_LENGTH, cl && *cl ? newSViv(atoi(SvPV_nolen(*cl))) : newSViv(-1));')
       ->blank
       ->line('av_store(self, RESP_SLOT_HTTP_VERSION, newSVpvn("1.1", 3));')
@@ -232,7 +247,7 @@ sub gen_xs_from_raw {
       ->line('av_store(self, RESP_SLOT_JSON, &PL_sv_undef);')
       ->line('av_store(self, RESP_SLOT_RAW_HEADERS, newSVpvn(raw, headers_len));')
       ->blank
-      ->line('SV* obj = sv_bless(newRV_noinc((SV*)self), gv_stashpv("Hypersonic::UA::Response", GV_ADD));')
+      ->line('obj = sv_bless(newRV_noinc((SV*)self), gv_stashpv("Hypersonic::UA::Response", GV_ADD));')
       ->line('ST(0) = sv_2mortal(obj);')
       ->xs_return('1')
       ->xs_end
@@ -311,8 +326,9 @@ sub gen_xs_header {
       ->line('const char* key = SvPV(ST(1), klen);')
       ->blank
       ->line('char norm_key[256];')
+      ->line('size_t i;')
       ->line('if (klen > 255) klen = 255;')
-      ->line('for (size_t i = 0; i < klen; i++) {')
+      ->line('for (i = 0; i < klen; i++) {')
       ->line('    char c = key[i];')
       ->line('    if (c >= \'A\' && c <= \'Z\') c += 32;')
       ->line('    else if (c == \'-\') c = \'_\';')
