@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant MAX_SSE_CONNS => 256;
 
@@ -80,7 +80,8 @@ sub gen_sse_registry {
 
     # Helper: find connection by fd
     $builder->line('static SSEConnection* sse_find(int fd) {')
-      ->line('    for (int i = 0; i < MAX_SSE_CONNS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < MAX_SSE_CONNS; i++) {')
       ->line('        if (sse_registry[i].fd == fd) {')
       ->line('            return &sse_registry[i];')
       ->line('        }')
@@ -91,7 +92,8 @@ sub gen_sse_registry {
 
     # Helper: allocate connection slot
     $builder->line('static SSEConnection* sse_alloc(int fd) {')
-      ->line('    for (int i = 0; i < MAX_SSE_CONNS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < MAX_SSE_CONNS; i++) {')
       ->line('        if (sse_registry[i].fd == 0) {')
       ->line('            SSEConnection* c = &sse_registry[i];')
       ->line('            memset(c, 0, sizeof(SSEConnection));')
@@ -237,7 +239,8 @@ sub gen_sse_parser {
       ->line('        else if (field_len == 5 && memcmp(field, "retry", 5) == 0) {')
       ->line('            int retry = 0;')
       ->line('            int valid = 1;')
-      ->line('            for (size_t i = 0; i < value_len; i++) {')
+      ->line('            size_t i;')
+      ->line('            for (i = 0; i < value_len; i++) {')
       ->line('                if (value[i] >= \'0\' && value[i] <= \'9\') {')
       ->line('                    retry = retry * 10 + (value[i] - \'0\');')
       ->line('                } else {')
@@ -268,19 +271,26 @@ sub gen_xs_new {
     $builder->comment('Create new SSE object')
       ->xs_function('xs_sse_new')
       ->xs_preamble
+      ->line('int fd;')
+      ->line('int retry;')
+      ->line('int reconnect;')
+      ->line('SSEConnection* c;')
+      ->line('AV* obj;')
+      ->line('SV* rv;')
+      ->blank
       ->line('if (items < 2) croak("Usage: Hypersonic::UA::SSE->new(fd, [retry], [reconnect])");')
       ->blank
-      ->line('int fd = (int)SvIV(ST(1));')
-      ->line('int retry = (items > 2) ? SvIV(ST(2)) : 3000;')
-      ->line('int reconnect = (items > 3) ? SvIV(ST(3)) : 1;')
+      ->line('fd = (int)SvIV(ST(1));')
+      ->line('retry = (items > 2) ? SvIV(ST(2)) : 3000;')
+      ->line('reconnect = (items > 3) ? SvIV(ST(3)) : 1;')
       ->blank
-      ->line('SSEConnection* c = sse_alloc(fd);')
+      ->line('c = sse_alloc(fd);')
       ->line('if (!c) croak("SSE registry full");')
       ->blank
       ->line('c->retry_ms = retry;')
       ->line('c->reconnect = reconnect;')
       ->blank
-      ->line('AV* obj = newAV();')
+      ->line('obj = newAV();')
       ->line('av_extend(obj, 4);')
       ->line('av_store(obj, 0, newSViv(fd));')
       ->line('av_store(obj, 1, &PL_sv_undef);')
@@ -288,7 +298,7 @@ sub gen_xs_new {
       ->line('av_store(obj, 3, newSViv(reconnect));')
       ->line('av_store(obj, 4, newSViv(retry));')
       ->blank
-      ->line('SV* rv = newRV_noinc((SV*)obj);')
+      ->line('rv = newRV_noinc((SV*)obj);')
       ->line('sv_bless(rv, gv_stashpv("Hypersonic::UA::SSE", GV_ADD));')
       ->line('ST(0) = sv_2mortal(rv);')
       ->xs_return('1')
@@ -302,12 +312,17 @@ sub gen_xs_connect {
     $builder->comment('Mark SSE connection as established')
       ->xs_function('xs_sse_connect')
       ->xs_preamble
-      ->line('if (items != 1) croak("Usage: $sse->connect()");')
-      ->line('AV* obj = (AV*)SvRV(ST(0));')
-      ->line('SV** fd_sv = av_fetch(obj, 0, 0);')
-      ->line('int fd = SvIV(*fd_sv);')
+      ->line('AV* obj;')
+      ->line('SV** fd_sv;')
+      ->line('int fd;')
+      ->line('SSEConnection* c;')
       ->blank
-      ->line('SSEConnection* c = sse_find(fd);')
+      ->line('if (items != 1) croak("Usage: $sse->connect()");')
+      ->line('obj = (AV*)SvRV(ST(0));')
+      ->line('fd_sv = av_fetch(obj, 0, 0);')
+      ->line('fd = SvIV(*fd_sv);')
+      ->blank
+      ->line('c = sse_find(fd);')
       ->line('if (c) {')
       ->line('    c->connected = 1;')
       ->line('    ST(0) = &PL_sv_yes;')
