@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant MAX_SOCKETS => 65536;
 use constant RECV_BUF_SIZE => 65536;
@@ -79,20 +79,25 @@ sub gen_xs_connect_to_host {
     $builder->comment('Connect to host with DNS resolution and timeout')
       ->xs_function('xs_socket_connect_to_host')
       ->xs_preamble
+      ->line('STRLEN host_len;')
+      ->line('const char* host;')
+      ->line('int port;')
+      ->line('int timeout_ms;')
+      ->line('struct addrinfo hints, *res, *rp;')
+      ->line('char port_str[8];')
+      ->line('int fd = -1;')
+      ->blank
       ->line('if (items != 3) croak("Usage: connect_to_host(host, port, timeout_ms)");')
       ->blank
-      ->line('STRLEN host_len;')
-      ->line('const char* host = SvPV(ST(0), host_len);')
-      ->line('int port = (int)SvIV(ST(1));')
-      ->line('int timeout_ms = (int)SvIV(ST(2));')
+      ->line('host = SvPV(ST(0), host_len);')
+      ->line('port = (int)SvIV(ST(1));')
+      ->line('timeout_ms = (int)SvIV(ST(2));')
       ->blank
       ->comment('DNS lookup')
-      ->line('struct addrinfo hints, *res, *rp;')
       ->line('memset(&hints, 0, sizeof(hints));')
       ->line('hints.ai_family = AF_UNSPEC;')
       ->line('hints.ai_socktype = SOCK_STREAM;')
       ->blank
-      ->line('char port_str[8];')
       ->line('snprintf(port_str, sizeof(port_str), "%d", port);')
       ->blank
       ->if('getaddrinfo(host, port_str, &hints, &res) != 0')
@@ -101,7 +106,6 @@ sub gen_xs_connect_to_host {
       ->endif
       ->blank
       ->comment('Try each address')
-      ->line('int fd = -1;')
       ->line('for (rp = res; rp != NULL; rp = rp->ai_next) {')
       ->line('    fd = socket(rp->ai_family, rp->ai_socktype, rp->ai_protocol);')
       ->line('    if (fd < 0) continue;')
@@ -155,19 +159,26 @@ sub gen_xs_connect_nonblocking {
     $builder->comment('Non-blocking connect - returns fd immediately')
       ->xs_function('xs_socket_connect_nonblocking')
       ->xs_preamble
+      ->line('STRLEN host_len;')
+      ->line('const char* host;')
+      ->line('int port;')
+      ->line('struct addrinfo hints, *res;')
+      ->line('char port_str[8];')
+      ->line('int fd;')
+      ->line('int flags;')
+      ->line('int opt;')
+      ->line('int ret;')
+      ->blank
       ->line('if (items != 2) croak("Usage: connect_nonblocking(host, port)");')
       ->blank
-      ->line('STRLEN host_len;')
-      ->line('const char* host = SvPV(ST(0), host_len);')
-      ->line('int port = (int)SvIV(ST(1));')
+      ->line('host = SvPV(ST(0), host_len);')
+      ->line('port = (int)SvIV(ST(1));')
       ->blank
       ->comment('DNS lookup')
-      ->line('struct addrinfo hints, *res;')
       ->line('memset(&hints, 0, sizeof(hints));')
       ->line('hints.ai_family = AF_UNSPEC;')
       ->line('hints.ai_socktype = SOCK_STREAM;')
       ->blank
-      ->line('char port_str[8];')
       ->line('snprintf(port_str, sizeof(port_str), "%d", port);')
       ->blank
       ->if('getaddrinfo(host, port_str, &hints, &res) != 0')
@@ -175,7 +186,7 @@ sub gen_xs_connect_nonblocking {
         ->line('XSRETURN(1);')
       ->endif
       ->blank
-      ->line('int fd = socket(res->ai_family, res->ai_socktype, res->ai_protocol);')
+      ->line('fd = socket(res->ai_family, res->ai_socktype, res->ai_protocol);')
       ->if('fd < 0')
         ->line('freeaddrinfo(res);')
         ->line('ST(0) = sv_2mortal(newSViv(-1));')
@@ -183,15 +194,15 @@ sub gen_xs_connect_nonblocking {
       ->endif
       ->blank
       ->comment('Set non-blocking')
-      ->line('int flags = fcntl(fd, F_GETFL, 0);')
+      ->line('flags = fcntl(fd, F_GETFL, 0);')
       ->line('fcntl(fd, F_SETFL, flags | O_NONBLOCK);')
       ->blank
       ->comment('Disable Nagle')
-      ->line('int opt = 1;')
+      ->line('opt = 1;')
       ->line('setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, &opt, sizeof(opt));')
       ->blank
       ->comment('Start non-blocking connect')
-      ->line('int ret = connect(fd, res->ai_addr, res->ai_addrlen);')
+      ->line('ret = connect(fd, res->ai_addr, res->ai_addrlen);')
       ->line('freeaddrinfo(res);')
       ->blank
       ->if('ret == 0 || errno == EINPROGRESS')
