@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant {
     STATE_INIT      => 0,
@@ -88,7 +88,8 @@ sub gen_stream_registry {
       ->blank;
 
     $builder->line('static UAStreamEntry* ua_stream_find(int fd) {')
-      ->line('    for (int i = 0; i < UA_MAX_STREAMS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < UA_MAX_STREAMS; i++) {')
       ->line('        if (ua_stream_registry[i].fd == fd) {')
       ->line('            return &ua_stream_registry[i];')
       ->line('        }')
@@ -98,7 +99,8 @@ sub gen_stream_registry {
       ->blank;
 
     $builder->line('static UAStreamEntry* ua_stream_alloc(int fd) {')
-      ->line('    for (int i = 0; i < UA_MAX_STREAMS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < UA_MAX_STREAMS; i++) {')
       ->line('        if (ua_stream_registry[i].fd == -1) {')
       ->line('            UAStreamEntry* s = &ua_stream_registry[i];')
       ->line('            memset(s, 0, sizeof(UAStreamEntry));')
@@ -168,7 +170,8 @@ sub gen_stream_registry {
       ->line('            if (val_len > 0 && val[val_len-1] == \'\\r\') val_len--;')
       ->blank
       ->line('            char name_lower[256];')
-      ->line('            for (size_t i = 0; i < name_len && i < 255; i++) {')
+      ->line('            size_t i;')
+      ->line('            for (i = 0; i < name_len && i < 255; i++) {')
       ->line('                char c = p[i];')
       ->line('                name_lower[i] = (c >= \'A\' && c <= \'Z\') ? c + 32 : (c == \'-\' ? \'_\' : c);')
       ->line('            }')
@@ -304,7 +307,8 @@ sub gen_stream_registry {
       ->blank;
 
     $builder->line('static void ua_stream_registry_init(void) {')
-      ->line('    for (int i = 0; i < UA_MAX_STREAMS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < UA_MAX_STREAMS; i++) {')
       ->line('        ua_stream_registry[i].fd = -1;')
       ->line('    }')
       ->line('}')
@@ -317,16 +321,22 @@ sub gen_xs_new {
     $builder->comment('Create new stream')
       ->xs_function('xs_uastream_new')
       ->xs_preamble
-      ->line('if (items < 2) croak("Usage: Hypersonic::UA::Stream->new(fd, [tls])");')
-      ->line('int fd = (int)SvIV(ST(1));')
-      ->line('int tls = (items > 2) ? (int)SvIV(ST(2)) : 0;')
+      ->line('int fd;')
+      ->line('int tls;')
+      ->line('UAStreamEntry* s;')
+      ->line('AV* obj;')
+      ->line('SV* rv;')
       ->blank
-      ->line('UAStreamEntry* s = ua_stream_alloc(fd);')
+      ->line('if (items < 2) croak("Usage: Hypersonic::UA::Stream->new(fd, [tls])");')
+      ->line('fd = (int)SvIV(ST(1));')
+      ->line('tls = (items > 2) ? (int)SvIV(ST(2)) : 0;')
+      ->blank
+      ->line('s = ua_stream_alloc(fd);')
       ->line('if (!s) croak("Stream registry full");')
       ->blank
       ->line('s->tls = tls;')
       ->blank
-      ->line('AV* obj = newAV();')
+      ->line('obj = newAV();')
       ->line('av_extend(obj, 4);')
       ->line('av_store(obj, 0, newSViv(fd));')
       ->line('av_store(obj, 1, &PL_sv_undef);')
@@ -334,7 +344,7 @@ sub gen_xs_new {
       ->line('av_store(obj, 3, &PL_sv_undef);')
       ->line('av_store(obj, 4, &PL_sv_undef);')
       ->blank
-      ->line('SV* rv = newRV_noinc((SV*)obj);')
+      ->line('rv = newRV_noinc((SV*)obj);')
       ->line('sv_bless(rv, gv_stashpv("Hypersonic::UA::Stream", GV_ADD));')
       ->line('ST(0) = sv_2mortal(rv);')
       ->xs_return('1')
@@ -348,9 +358,12 @@ sub gen_xs_fd {
     $builder->comment('Get stream fd')
       ->xs_function('xs_uastream_fd')
       ->xs_preamble
+      ->line('AV* obj;')
+      ->line('SV** fd_sv;')
+      ->blank
       ->line('if (items != 1) croak("Usage: $stream->fd()");')
-      ->line('AV* obj = (AV*)SvRV(ST(0));')
-      ->line('SV** fd_sv = av_fetch(obj, 0, 0);')
+      ->line('obj = (AV*)SvRV(ST(0));')
+      ->line('fd_sv = av_fetch(obj, 0, 0);')
       ->line('ST(0) = fd_sv ? *fd_sv : &PL_sv_undef;')
       ->xs_return('1')
       ->xs_end
@@ -363,12 +376,17 @@ sub gen_xs_state {
     $builder->comment('Get stream state')
       ->xs_function('xs_uastream_state')
       ->xs_preamble
-      ->line('if (items != 1) croak("Usage: $stream->state()");')
-      ->line('AV* obj = (AV*)SvRV(ST(0));')
-      ->line('SV** fd_sv = av_fetch(obj, 0, 0);')
-      ->line('int fd = (int)SvIV(*fd_sv);')
+      ->line('AV* obj;')
+      ->line('SV** fd_sv;')
+      ->line('int fd;')
+      ->line('UAStreamEntry* s;')
       ->blank
-      ->line('UAStreamEntry* s = ua_stream_find(fd);')
+      ->line('if (items != 1) croak("Usage: $stream->state()");')
+      ->line('obj = (AV*)SvRV(ST(0));')
+      ->line('fd_sv = av_fetch(obj, 0, 0);')
+      ->line('fd = (int)SvIV(*fd_sv);')
+      ->blank
+      ->line('s = ua_stream_find(fd);')
       ->line('ST(0) = s ? sv_2mortal(newSViv(s->state)) : &PL_sv_undef;')
       ->xs_return('1')
       ->xs_end
