@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant MAX_TLS_CONNS => 10000;
 
@@ -88,7 +88,8 @@ sub gen_tls_registry {
       ->blank;
 
     $builder->line('static UATLSClientConn* ua_tls_find(int fd) {')
-      ->line('    for (int i = 0; i < UA_MAX_TLS_CONNS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < UA_MAX_TLS_CONNS; i++) {')
       ->line('        if (ua_tls_registry[i].fd == fd) {')
       ->line('            return &ua_tls_registry[i];')
       ->line('        }')
@@ -98,7 +99,8 @@ sub gen_tls_registry {
       ->blank;
 
     $builder->line('static UATLSClientConn* ua_tls_alloc(int fd) {')
-      ->line('    for (int i = 0; i < UA_MAX_TLS_CONNS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < UA_MAX_TLS_CONNS; i++) {')
       ->line('        if (ua_tls_registry[i].fd == 0) {')
       ->line('            UATLSClientConn* c = &ua_tls_registry[i];')
       ->line('            memset(c, 0, sizeof(UATLSClientConn));')
@@ -133,10 +135,13 @@ sub gen_xs_init_context {
     $builder->comment('Initialize client TLS context')
       ->xs_function('xs_uatls_init_context')
       ->xs_preamble
+      ->line('int verify;')
+      ->line('const char* ca_file;')
+      ->blank
       ->line('if (items > 2) croak("Usage: init_context([verify], [ca_file])");')
       ->blank
-      ->line('int verify = (items > 0) ? (int)SvIV(ST(0)) : 1;')
-      ->line('const char* ca_file = (items > 1 && SvOK(ST(1))) ? SvPV_nolen(ST(1)) : NULL;')
+      ->line('verify = (items > 0) ? (int)SvIV(ST(0)) : 1;')
+      ->line('ca_file = (items > 1 && SvOK(ST(1))) ? SvPV_nolen(ST(1)) : NULL;')
       ->blank
       ->line('SSL_library_init();')
       ->line('SSL_load_error_strings();')
@@ -175,12 +180,20 @@ sub gen_xs_connect {
     $builder->comment('TLS connect with SNI and verification')
       ->xs_function('xs_uatls_connect')
       ->xs_preamble
+      ->line('int fd;')
+      ->line('STRLEN host_len;')
+      ->line('const char* hostname;')
+      ->line('int verify;')
+      ->line('SSL* ssl;')
+      ->line('int ret;')
+      ->line('int err;')
+      ->line('UATLSClientConn* c;')
+      ->blank
       ->line('if (items < 2 || items > 3) croak("Usage: tls_connect(fd, hostname, [verify])");')
       ->blank
-      ->line('int fd = (int)SvIV(ST(0));')
-      ->line('STRLEN host_len;')
-      ->line('const char* hostname = SvPV(ST(1), host_len);')
-      ->line('int verify = (items > 2) ? (int)SvIV(ST(2)) : 1;')
+      ->line('fd = (int)SvIV(ST(0));')
+      ->line('hostname = SvPV(ST(1), host_len);')
+      ->line('verify = (items > 2) ? (int)SvIV(ST(2)) : 1;')
       ->blank
       ->if('!g_ua_client_ssl_ctx')
         ->line('SSL_library_init();')
@@ -194,7 +207,7 @@ sub gen_xs_connect {
         ->line('ua_tls_registry_init();')
       ->endif
       ->blank
-      ->line('SSL* ssl = SSL_new(g_ua_client_ssl_ctx);')
+      ->line('ssl = SSL_new(g_ua_client_ssl_ctx);')
       ->if('!ssl')
         ->line('ST(0) = sv_2mortal(newSViv(-1));')
         ->line('XSRETURN(1);')
@@ -211,15 +224,15 @@ sub gen_xs_connect {
         ->line('SSL_set1_host(ssl, hostname);')
       ->endif
       ->blank
-      ->line('int ret = SSL_connect(ssl);')
+      ->line('ret = SSL_connect(ssl);')
       ->if('ret != 1')
-        ->line('int err = SSL_get_error(ssl, ret);')
+        ->line('err = SSL_get_error(ssl, ret);')
         ->line('SSL_free(ssl);')
         ->line('ST(0) = sv_2mortal(newSViv(-err));')
         ->line('XSRETURN(1);')
       ->endif
       ->blank
-      ->line('UATLSClientConn* c = ua_tls_alloc(fd);')
+      ->line('c = ua_tls_alloc(fd);')
       ->if('!c')
         ->line('SSL_free(ssl);')
         ->line('ST(0) = sv_2mortal(newSViv(-999));')
