@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use constant MAX_WS_CLIENT_CONNS => 1024;
 
@@ -120,7 +120,8 @@ sub gen_websocket_registry {
       ->blank;
 
     $builder->line('static int ws_client_alloc_slot(void) {')
-      ->line('    for (int i = 0; i < MAX_WS_CLIENT_CONNS; i++) {')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < MAX_WS_CLIENT_CONNS; i++) {')
       ->line('        if (!ws_client_registry[i].in_use) {')
       ->line('            memset(&ws_client_registry[i], 0, sizeof(WSClientConnection));')
       ->line('            ws_client_registry[i].in_use = 1;')
@@ -178,6 +179,7 @@ sub gen_frame_encoder {
 
     $builder->line('static size_t ws_client_encode_frame(unsigned char *out, const unsigned char *data, size_t data_len, int opcode, int fin) {')
       ->line('    size_t offset = 0;')
+      ->line('    size_t i;')
       ->blank
       ->line('    out[offset++] = (fin ? 0x80 : 0x00) | (opcode & 0x0F);')
       ->blank
@@ -202,7 +204,7 @@ sub gen_frame_encoder {
       ->line('    memcpy(out + offset, mask, 4);')
       ->line('    offset += 4;')
       ->blank
-      ->line('    for (size_t i = 0; i < data_len; i++) {')
+      ->line('    for (i = 0; i < data_len; i++) {')
       ->line('        out[offset + i] = data[i] ^ mask[i & 3];')
       ->line('    }')
       ->blank
@@ -231,6 +233,7 @@ sub gen_frame_decoder {
       ->blank;
 
     $builder->line('static int ws_client_decode_frame(const unsigned char *buf, size_t buf_len, WSFrame *frame) {')
+      ->line('    size_t i;')
       ->line('    if (buf_len < 2) return 0;')
       ->blank
       ->line('    frame->fin = (buf[0] >> 7) & 1;')
@@ -264,7 +267,7 @@ sub gen_frame_decoder {
       ->line('    frame->consumed = header_len + payload_len;')
       ->blank
       ->line('    if (masked && payload_len > 0) {')
-      ->line('        for (size_t i = 0; i < payload_len; i++) {')
+      ->line('        for (i = 0; i < payload_len; i++) {')
       ->line('            frame->payload[i] ^= mask_key[i & 3];')
       ->line('        }')
       ->line('    }')
