@@ -8,7 +8,7 @@ use warnings;
 # This module generates XS functions callable from Perl.
 # Object-oriented API: $conn = Handler->new($fd, $ws); $conn->send($msg);
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # Maximum concurrent WebSocket connections
 use constant MAX_CONNECTIONS => 65536;
@@ -77,18 +77,24 @@ sub gen_xs_new {
     
     $builder->xs_function('xs_ws_new')
       ->xs_preamble
+      ->line('int fd;')
+      ->line('SV* ws;')
+      ->line('WSConnection* conn;')
+      ->line('SV* fd_sv;')
+      ->line('SV* fd_ref;')
+      ->blank
       ->if('items != 3')
         ->line('croak("Usage: Hypersonic::WebSocket::Handler->new(fd, ws)");')
       ->endif
       ->blank
-      ->line('int fd = SvIV(ST(1));')
-      ->line('SV* ws = ST(2);')
+      ->line('fd = SvIV(ST(1));')
+      ->line('ws = ST(2);')
       ->blank
       ->if('fd < 0 || fd >= WS_MAX_CONNECTIONS')
         ->line('croak("fd out of range: %d", fd);')
       ->endif
       ->blank
-      ->line('WSConnection* conn = &ws_handler_registry[fd];')
+      ->line('conn = &ws_handler_registry[fd];')
       ->if('conn->active')
         ->comment('Already registered, return existing')
       ->else
@@ -100,8 +106,8 @@ sub gen_xs_new {
       ->endif
       ->blank
       ->comment('Create blessed object: bless \\$fd, class')
-      ->line('SV* fd_sv = newSViv(fd);')
-      ->line('SV* fd_ref = newRV_noinc(fd_sv);')
+      ->line('fd_sv = newSViv(fd);')
+      ->line('fd_ref = newRV_noinc(fd_sv);')
       ->line('sv_bless(fd_ref, gv_stashpv("Hypersonic::WebSocket::Handler", GV_ADD));')
       ->line('ST(0) = sv_2mortal(fd_ref);')
       ->line('XSRETURN(1);')
@@ -117,11 +123,13 @@ sub gen_xs_fd {
     
     $builder->xs_function('xs_ws_fd')
       ->xs_preamble
+      ->line('int fd;')
+      ->blank
       ->if('items != 1')
         ->line('croak("Usage: $conn->fd()");')
       ->endif
       ->blank
-      ->line('int fd = SvIV(SvRV(ST(0)));')
+      ->line('fd = SvIV(SvRV(ST(0)));')
       ->line('XSRETURN_IV(fd);')
       ->xs_end
       ->blank;
@@ -135,11 +143,13 @@ sub gen_xs_state {
     
     $builder->xs_function('xs_ws_state')
       ->xs_preamble
+      ->line('int fd;')
+      ->blank
       ->if('items != 1')
         ->line('croak("Usage: $conn->state()");')
       ->endif
       ->blank
-      ->line('int fd = SvIV(SvRV(ST(0)));')
+      ->line('fd = SvIV(SvRV(ST(0)));')
       ->blank
       ->if('fd < 0 || fd >= WS_MAX_CONNECTIONS')
         ->line('XSRETURN_IV(-1);')
@@ -463,6 +473,7 @@ sub gen_xs_broadcast {
       ->line('STRLEN msg_len;')
       ->line('const char* message = SvPV(ST(1), msg_len);')
       ->line('int exclude_fd = -1;')
+      ->line('int fd;')
       ->blank
       ->comment('Handle exclude - can be fd or Handler object')
       ->if('items >= 3')
@@ -492,7 +503,7 @@ sub gen_xs_broadcast {
       ->endif
       ->blank
       ->line('int sent = 0;')
-      ->for('int fd = 0', 'fd < WS_MAX_CONNECTIONS', 'fd++')
+      ->for('fd = 0', 'fd < WS_MAX_CONNECTIONS', 'fd++')
         ->if('ws_handler_registry[fd].active && ws_handler_registry[fd].state == WS_STATE_OPEN && fd != exclude_fd')
           ->line('send(fd, frame, frame_len, 0);')
           ->line('sent++;')
