@@ -7,7 +7,7 @@ use warnings;
 # All room management is done in C via XS::JIT::Builder.
 # This module generates XS functions callable from Perl.
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # Maximum rooms and clients per room
 use constant MAX_ROOMS => 1000;
@@ -63,21 +63,23 @@ sub gen_room_registry {
       ->blank
       ->comment('Find room by name, returns index or -1')
       ->line('static int find_room_by_name(const char* name) {')
-      ->for('int i = 0', 'i < ROOM_MAX_ROOMS', 'i++')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < ROOM_MAX_ROOMS; i++) {')
         ->if('room_registry[i].active && strcmp(room_registry[i].name, name) == 0')
           ->line('return i;')
         ->endif
-      ->endfor
+      ->line('    }')
       ->line('return -1;')
       ->line('}')
       ->blank
       ->comment('Find free room slot')
       ->line('static int find_free_room_slot() {')
-      ->for('int i = 0', 'i < ROOM_MAX_ROOMS', 'i++')
+      ->line('    int i;')
+      ->line('    for (i = 0; i < ROOM_MAX_ROOMS; i++) {')
         ->if('!room_registry[i].active')
           ->line('return i;')
         ->endif
-      ->endfor
+      ->line('    }')
       ->line('return -1;')
       ->line('}')
       ->blank
@@ -110,15 +112,21 @@ sub gen_xs_new {
     
     $builder->xs_function('xs_room_new')
       ->xs_preamble
+      ->line('STRLEN name_len;')
+      ->line('const char* name;')
+      ->line('int room_id;')
+      ->line('WSRoom* room;')
+      ->line('SV* room_sv;')
+      ->line('SV* room_ref;')
+      ->blank
       ->if('items != 2')
         ->line('croak("Usage: Hypersonic::WebSocket::Room->new(name)");')
       ->endif
       ->blank
-      ->line('STRLEN name_len;')
-      ->line('const char* name = SvPV(ST(1), name_len);')
+      ->line('name = SvPV(ST(1), name_len);')
       ->blank
       ->comment('Check if room already exists')
-      ->line('int room_id = find_room_by_name(name);')
+      ->line('room_id = find_room_by_name(name);')
       ->if('room_id < 0')
         ->comment('Find free slot')
         ->line('room_id = find_free_room_slot();')
@@ -126,7 +134,7 @@ sub gen_xs_new {
           ->line('croak("Maximum rooms reached");')
         ->endif
         ->blank
-        ->line('WSRoom* room = &room_registry[room_id];')
+        ->line('room = &room_registry[room_id];')
         ->line('room->active = 1;')
         ->if('name_len >= sizeof(room->name)')
           ->line('name_len = sizeof(room->name) - 1;')
@@ -139,8 +147,8 @@ sub gen_xs_new {
       ->endif
       ->blank
       ->comment('Create blessed object: bless \\$room_id, class')
-      ->line('SV* room_sv = newSViv(room_id);')
-      ->line('SV* room_ref = newRV_noinc(room_sv);')
+      ->line('room_sv = newSViv(room_id);')
+      ->line('room_ref = newRV_noinc(room_sv);')
       ->line('sv_bless(room_ref, gv_stashpv("Hypersonic::WebSocket::Room", GV_ADD));')
       ->line('ST(0) = sv_2mortal(room_ref);')
       ->line('XSRETURN(1);')
@@ -184,12 +192,17 @@ sub gen_xs_join {
     
     $builder->xs_function('xs_room_join')
       ->xs_preamble
+      ->line('int room_id;')
+      ->line('int fd;')
+      ->line('int i;')
+      ->line('WSRoom* room;')
+      ->blank
       ->if('items != 2')
         ->line('croak("Usage: $room->join(fd)");')
       ->endif
       ->blank
-      ->line('int room_id = SvIV(SvRV(ST(0)));')
-      ->line('int fd = extract_fd(ST(1));')
+      ->line('room_id = SvIV(SvRV(ST(0)));')
+      ->line('fd = extract_fd(ST(1));')
       ->blank
       ->if('fd < 0')
         ->line('XSRETURN_NO;')
@@ -201,14 +214,14 @@ sub gen_xs_join {
         ->line('XSRETURN_NO;')
       ->endif
       ->blank
-      ->line('WSRoom* room = &room_registry[room_id];')
+      ->line('room = &room_registry[room_id];')
       ->blank
       ->comment('Check if already in room')
-      ->for('int i = 0', 'i < room->client_count', 'i++')
+      ->line('for (i = 0; i < room->client_count; i++) {')
         ->if('room->client_fds[i] == fd')
           ->line('XSRETURN_YES;')
         ->endif
-      ->endfor
+      ->line('}')
       ->blank
       ->comment('Add to room')
       ->if('room->client_count >= ROOM_MAX_CLIENTS')
@@ -229,12 +242,17 @@ sub gen_xs_leave {
     
     $builder->xs_function('xs_room_leave')
       ->xs_preamble
+      ->line('int room_id;')
+      ->line('int fd;')
+      ->line('int i;')
+      ->line('WSRoom* room;')
+      ->blank
       ->if('items != 2')
         ->line('croak("Usage: $room->leave(fd)");')
       ->endif
       ->blank
-      ->line('int room_id = SvIV(SvRV(ST(0)));')
-      ->line('int fd = extract_fd(ST(1));')
+      ->line('room_id = SvIV(SvRV(ST(0)));')
+      ->line('fd = extract_fd(ST(1));')
       ->blank
       ->if('fd < 0')
         ->line('XSRETURN_NO;')
@@ -246,17 +264,17 @@ sub gen_xs_leave {
         ->line('XSRETURN_NO;')
       ->endif
       ->blank
-      ->line('WSRoom* room = &room_registry[room_id];')
+      ->line('room = &room_registry[room_id];')
       ->blank
       ->comment('Find and remove')
-      ->for('int i = 0', 'i < room->client_count', 'i++')
+      ->line('for (i = 0; i < room->client_count; i++) {')
         ->if('room->client_fds[i] == fd')
           ->comment('Shift remaining down')
           ->line('memmove(&room->client_fds[i], &room->client_fds[i+1], (room->client_count - i - 1) * sizeof(int));')
           ->line('room->client_count--;')
           ->line('XSRETURN_YES;')
         ->endif
-      ->endfor
+      ->line('}')
       ->blank
       ->line('XSRETURN_NO;')
       ->xs_end
@@ -271,12 +289,17 @@ sub gen_xs_has {
     
     $builder->xs_function('xs_room_has')
       ->xs_preamble
+      ->line('int room_id;')
+      ->line('int fd;')
+      ->line('int i;')
+      ->line('WSRoom* room;')
+      ->blank
       ->if('items != 2')
         ->line('croak("Usage: $room->has(fd)");')
       ->endif
       ->blank
-      ->line('int room_id = SvIV(SvRV(ST(0)));')
-      ->line('int fd = extract_fd(ST(1));')
+      ->line('room_id = SvIV(SvRV(ST(0)));')
+      ->line('fd = extract_fd(ST(1));')
       ->blank
       ->if('fd < 0')
         ->line('XSRETURN_NO;')
@@ -288,12 +311,12 @@ sub gen_xs_has {
         ->line('XSRETURN_NO;')
       ->endif
       ->blank
-      ->line('WSRoom* room = &room_registry[room_id];')
-      ->for('int i = 0', 'i < room->client_count', 'i++')
+      ->line('room = &room_registry[room_id];')
+      ->line('for (i = 0; i < room->client_count; i++) {')
         ->if('room->client_fds[i] == fd')
           ->line('XSRETURN_YES;')
         ->endif
-      ->endfor
+      ->line('}')
       ->blank
       ->line('XSRETURN_NO;')
       ->xs_end
@@ -316,6 +339,7 @@ sub gen_xs_broadcast {
       ->line('STRLEN msg_len;')
       ->line('const char* message = SvPV(ST(1), msg_len);')
       ->line('int exclude_fd = (items >= 3) ? extract_fd(ST(2)) : -1;')
+      ->line('int i;')
       ->blank
       ->if('room_id < 0 || room_id >= ROOM_MAX_ROOMS')
         ->line('XSRETURN_IV(0);')
@@ -334,7 +358,7 @@ sub gen_xs_broadcast {
       ->endif
       ->blank
       ->line('int sent = 0;')
-      ->for('int i = 0', 'i < room->client_count', 'i++')
+      ->for('i = 0', 'i < room->client_count', 'i++')
         ->line('int fd = room->client_fds[i];')
         ->if('fd >= 0 && fd != exclude_fd')
           ->line('send(fd, frame, frame_len, 0);')
@@ -363,6 +387,7 @@ sub gen_xs_broadcast_binary {
       ->line('STRLEN data_len;')
       ->line('const char* data = SvPV(ST(1), data_len);')
       ->line('int exclude_fd = (items >= 3) ? extract_fd(ST(2)) : -1;')
+      ->line('int i;')
       ->blank
       ->if('room_id < 0 || room_id >= ROOM_MAX_ROOMS')
         ->line('XSRETURN_IV(0);')
@@ -381,7 +406,7 @@ sub gen_xs_broadcast_binary {
       ->endif
       ->blank
       ->line('int sent = 0;')
-      ->for('int i = 0', 'i < room->client_count', 'i++')
+      ->for('i = 0', 'i < room->client_count', 'i++')
         ->line('int fd = room->client_fds[i];')
         ->if('fd >= 0 && fd != exclude_fd')
           ->line('send(fd, frame, frame_len, 0);')
@@ -444,9 +469,10 @@ sub gen_xs_count_open {
       ->line('WSRoom* room = &room_registry[room_id];')
       ->line('int open_count = 0;')
       ->line('int write_idx = 0;')
+      ->line('int i;')
       ->blank
       ->comment('Compact array, removing closed connections')
-      ->for('int i = 0', 'i < room->client_count', 'i++')
+      ->for('i = 0', 'i < room->client_count', 'i++')
         ->line('int fd = room->client_fds[i];')
         ->comment('Check if fd is still valid/open in handler registry')
         ->if('fd >= 0 && fd < WS_MAX_CONNECTIONS && ws_handler_registry[fd].active')
@@ -485,6 +511,7 @@ sub gen_xs_close_all {
       ->blank
       ->line('WSRoom* room = &room_registry[room_id];')
       ->line('int closed = 0;')
+      ->line('int i;')
       ->blank
       ->comment('Send close frame to all clients')
       ->line('uint8_t close_frame[4];')
@@ -493,7 +520,7 @@ sub gen_xs_close_all {
       ->line('close_frame[2] = (code >> 8) & 0xFF;')
       ->line('close_frame[3] = code & 0xFF;')
       ->blank
-      ->for('int i = 0', 'i < room->client_count', 'i++')
+      ->for('i = 0', 'i < room->client_count', 'i++')
         ->line('int fd = room->client_fds[i];')
         ->if('fd >= 0')
           ->line('send(fd, close_frame, 4, 0);')
@@ -588,8 +615,9 @@ sub gen_xs_clients {
       ->blank
       ->line('WSRoom* room = &room_registry[room_id];')
       ->line('int count = 0;')
+      ->line('int i;')
       ->blank
-      ->for('int i = 0', 'i < room->client_count', 'i++')
+      ->for('i = 0', 'i < room->client_count', 'i++')
         ->if('room->client_fds[i] >= 0')
           ->line('XPUSHs(sv_2mortal(newSViv(room->client_fds[i])));')
           ->line('count++;')
